@@ -35,7 +35,7 @@
 #-------------------------------------------------------------------------
 #END_LICENSE
 
-define('MINIMUM_REPOSITORY_VERSION','1.1');
+define('MINIMUM_REPOSITORY_VERSION','1.3');
 
 function uasort_cmp_details( $e1, $e2 )
 {
@@ -73,7 +73,7 @@ class ModuleManager extends CMSModule
    ---------------------------------------------------------*/
   function GetVersion()
   {
-    return '1.2.1';
+    return '1.3.3';
   }
 
 
@@ -230,8 +230,7 @@ class ModuleManager extends CMSModule
    ---------------------------------------------------------*/
   function MinimumCMSVersion()
   {
-    // TODO: THIS SHOULD BE 1.0.4-svn OR SOMETHING
-    return "1.0.4";
+    return "1.6-beta1";
   }
 
 
@@ -325,6 +324,12 @@ class ModuleManager extends CMSModule
 	}
 	break;
 
+      case 'moduledepends':
+	{
+	  $this->_DisplayAdminSoapModuleDepends( $id, $params, $returnid );
+	}
+	break;
+
       case 'moduleabout':
 	{
 	  $this->_DisplayAdminSoapModuleAbout( $id, $params, $returnid );
@@ -346,6 +351,7 @@ class ModuleManager extends CMSModule
   function _BuildModuleData( &$xmldetails, &$installdetails )
   {
     global $CMS_VERSION;
+    if( !is_array($xmldetails) ) return;
 
     // sort
     uasort( $xmldetails, 'uasort_cmp_details' );
@@ -458,11 +464,11 @@ class ModuleManager extends CMSModule
     {
       $newest = $this->GetPreference('onlynewest',1);
       $result = $this->_GetRepositoryModules($curletter,$newest);
-//       if( ! $result[0] )
-// 	{
-// 	  $this->_DisplayErrorPage( $id, $params, $returnid, $result[1] );
-// 	  return;
-// 	}
+       if( ! $result[0] )
+ 	{
+ 	  $this->_DisplayErrorPage( $id, $params, $returnid, $result[1] );
+ 	  return;
+	}
       $repmodules = $result[1];
     }
 
@@ -490,7 +496,7 @@ class ModuleManager extends CMSModule
 	  }
 	else
 	  {
-	    $letters[] = $this->CreateLink($id,'defaultadmin',$returnid, $i, array('curletter'=>$i));
+	    $letters[] = $this->CreateLink($id,'defaultadmin',$returnid, $i, array('curletter'=>$i,'active_tab'=>'modules'));
 	  }
       }
 
@@ -522,6 +528,11 @@ class ModuleManager extends CMSModule
 						   array('name' => $row['name'],
 							 'version' => $row['version'],
 							 'filename' => $row['filename']));
+	    $onerow->dependslink = $this->CreateLink( $id, 'moduledepends', $returnid,
+						   $this->Lang('dependstxt'), 
+						   array('name' => $row['name'],
+							 'version' => $row['version'],
+							 'filename' => $row['filename']));
 	    $onerow->aboutlink = $this->CreateLink( $id, 'moduleabout', $returnid,
 						    $this->Lang('abouttxt'), 
 						    array('name' => $row['name'],
@@ -566,7 +577,7 @@ class ModuleManager extends CMSModule
 		       ($writable && !file_exists( $mod ) )) && $caninstall )
 		    {
 		      $onerow->status = $this->CreateLink( $id, 'upgrademodule', $returnid,
-							   $this->Lang('download'), 
+							   $this->Lang('upgrade'), 
 							   array('name' => $row['name'],
 								 'version' => $row['version'],
 								 'filename' => $row['filename'],
@@ -597,6 +608,12 @@ class ModuleManager extends CMSModule
       {
 	$this->smarty->assign('message', $this->Lang('error_connectnomodules'));
       }
+    // Setup search form
+    $searchstart = $this->CreateFormStart( $id, 'searchmod', $returnid );
+    $searchend = $this->CreateFormEnd();
+    $searchfield = $this->CreateInputText($id, 'search_input', "Doesn't Work",  30, 100); //todo
+    $searchsubmit = $this->CreateInputSubmit( $id, 'submit', 'Search'); // todo -- $this->Lang('search'));
+    $this->smarty->assign('search',$searchstart.$searchfield.$searchsubmit.$searchend);
 
     // and display our page
     $this->smarty->assign('letters', implode('&nbsp;',array_values($letters)));
@@ -609,7 +626,7 @@ class ModuleManager extends CMSModule
 
 
   /*---------------------------------------------------------
-   _DisplayAdminModulesTab()
+   _DisplayAdminPrefsTab()
    ---------------------------------------------------------*/
   function _DisplayAdminPrefsTab($id, &$params, $returnid)
   {
@@ -643,6 +660,96 @@ class ModuleManager extends CMSModule
     echo $this->ProcessTemplate('adminprefs.tpl');
   }
 
+  /*---------------------------------------------------------
+   _DisplayAdminSoapModuleDepends()
+   Display the help for an a module on the repository
+   ---------------------------------------------------------*/
+  function _DisplayAdminSoapModuleDepends($id, &$params, $returnid)
+  {
+    if( !isset( $params['name'] ) )
+      {
+	$this->_DisplayErrorPage( $id, $params, $returnid,
+				  $this->Lang('error_insufficientparams'));
+	return;
+      }
+    $name = $params['name'];
+
+    if( !isset( $params['version'] ) )
+      {
+	$this->_DisplayErrorPage( $id, $params, $returnid,
+				  $this->Lang('error_insufficientparams'));
+	return;
+      }
+    $version = $params['version'];
+
+    $url = $this->GetPreference('module_repository');
+    if( $url == '' )
+      {
+	$this->_DisplayErrorPage( $id, $params, $returnid,
+				  $this->Lang('error_norepositoryurl'));
+	return;
+      }
+
+    if( !isset($params['filename'] ) )
+      {
+	$this->_DisplayErrorPage( $id, $params, $returnid,
+				  $this->Lang('error_nofilename'));
+	return;
+      }
+    $xmlfile = $params['filename'];
+
+    $nusoap =& $this->GetModuleInstance('nuSOAP');
+    $nusoap->Load();
+    $nu_soapclient = new nu_soapclient($url,false,false,false,false,false,90,90);
+    if( $err = $nu_soapclient->GetError() )
+      {
+	$this->_DisplayErrorPage( $id, $params, $returnid,
+				  'SOAP Error: '.$err);
+	return;
+      }
+
+    $depends = $nu_soapclient->call('ModuleRepository.soap_moduledepends',array('name' => $xmlfile ));
+    if( $err = $nu_soapclient->GetError() )
+      {
+	$this->_DisplayErrorPage( $id, $params, $returnid,
+				  'SOAP Error: '.$err);
+	echo htmlspecialchars($nu_soapclient->response);
+	return;
+      }
+    if( $depends[0] == false )
+      {
+	$this->_DisplayErrorPage( $id, $params, $returnid,
+				  $depends[1] );
+	return;
+      }
+
+    $this->smarty->assign('title',$this->Lang('dependstxt'));
+    $this->smarty->assign('moduletext',$this->Lang('nametext'));
+    $this->smarty->assign('vertext',$this->Lang('vertext'));
+    $this->smarty->assign('xmltext',$this->Lang('xmltext'));
+    $this->smarty->assign('modulename',$name);
+    $this->smarty->assign('moduleversion',$version);
+    $this->smarty->assign('xmlfile',$xmlfile);
+
+    $txt = '';
+    if( is_array($depends[1]) )
+      {
+	$txt = '<ul>';
+	foreach( $depends[1] as $one )
+	  {
+	    $txt .= '<li>'.$one['name'].' => '.$one['version'].'</li>';
+	  }
+	$txt .= '</ul>';
+      }
+    else
+      {
+	$txt = $this->Lang('msg_nodependencies');
+      }
+    $this->smarty->assign('content',$txt);
+    echo $this->ProcessTemplate('remotecontent.tpl');
+  }
+
+
   /*---------------------------------------------------------
    _DisplayAdminSoapModuleHelp()
    Display the help for an a module on the repository
@@ -683,7 +790,7 @@ class ModuleManager extends CMSModule
 
     $nusoap =& $this->GetModuleInstance('nuSOAP');
     $nusoap->Load();
-    $nu_soapclient =& new nu_soapclient($url,false,false,false,false,false,90,90);
+    $nu_soapclient = new nu_soapclient($url,false,false,false,false,false,90,90);
     if( $err = $nu_soapclient->GetError() )
       {
 	$this->_DisplayErrorPage( $id, $params, $returnid,
@@ -756,7 +863,7 @@ class ModuleManager extends CMSModule
 
     $nusoap =& $this->GetModuleInstance('nuSOAP');
     $nusoap->Load();
-    $nu_soapclient =& new nu_soapclient($url,false,false,false,false,false,90,90);
+    $nu_soapclient = new nu_soapclient($url,false,false,false,false,false,90,90);
     if( $err = $nu_soapclient->GetError() )
       {
 	$this->_DisplayErrorPage( $id, $params, $returnid,
@@ -839,7 +946,7 @@ class ModuleManager extends CMSModule
 
     $nusoap =& $this->GetModuleInstance('nuSOAP');
     $nusoap->Load();
-    $nu_soapclient =& new nu_soapclient($url,false,false,false,false,false,90,90);
+    $nu_soapclient = new nu_soapclient($url,false,false,false,false,false,90,90);
     if( $err = $nu_soapclient->GetError() )
       {
 	$this->_DisplayErrorPage( $id, $params, $returnid,
@@ -847,10 +954,59 @@ class ModuleManager extends CMSModule
 	return;
       }
 
+    // get the dependencies from soap
+    $depends = $nu_soapclient->call('ModuleRepository.soap_moduledepends',array('name' => $xmlfile ));
+    if( $err = $nu_soapclient->GetError() )
+      {
+	$this->_DisplayErrorPage( $id, $params, $returnid,
+				  'SOAP Error: '.$err);
+	echo htmlspecialchars($nu_soapclient->response);
+	return;
+      }
+    if( $depends[0] == false )
+      {
+	$this->_DisplayErrorPage( $id, $params, $returnid,
+				  $depends[1] );
+	return;
+      }
+    if( is_array($depends[1]) )
+      {
+	global $gCms;
+	// check dependencies against what is installed.
+	$tmp = array();
+	foreach( $depends[1] as $onedep )
+	  {
+	    if( isset($gCms->modules[$onedep['name']]) ) 
+	      {
+		$mod =& $gCms->modules[$onedep['name']]['object'];
+		if( is_object($mod) )
+		  {
+		    if( version_compare($mod->GetVersion(),$onedep['version']) >= 0 )
+		      {
+			continue;
+		      }
+		  }
+	      }
+	    $tmp[] = $onedep;
+	  }
+
+	if( count($tmp) )
+	  {
+	    $txt = $this->Lang('error_depends').'<br/>';
+	    $txt .= '<ul>';
+	    foreach( $tmp as $one )
+	      {
+		$txt  .= '<li>'.$one['name'].' => '.$one['version'].'<br/>';
+	      }
+            $txt .= '</ul>';
+	    $this->_DisplayErrorPage( $id, $params, $returnid, $txt );
+	    return;
+	  }
+      }
+
     // get the xml file from soap
     $xml = '';
     $result = $this->_GetRepositoryXML($nu_soapclient,$xmlfile,$size,$xml);
-//     $xml = $nu_soapclient->call('ModuleRepository.soap_modulexml',array('name' => $xmlfile ));
     if( $err = $nu_soapclient->GetError() )
       {
 	echo "<pre>".htmlspecialchars($nu_soapclient->response)."</pre><br/>";
@@ -1031,7 +1187,7 @@ class ModuleManager extends CMSModule
 
     $nusoap =& $this->GetModuleInstance('nuSOAP');
     $nusoap->Load();
-    $nu_soapclient =& new nu_soapclient($url,false,false,false,false,false,90,90);
+    $nu_soapclient = new nu_soapclient($url,false,false,false,false,false,90,90);
     if( $err = $nu_soapclient->GetError() )
       {
 	return array(false,$this->Lang('error_nosoapconnect'));
