@@ -5,12 +5,12 @@ $lang['error_module_object'] = 'Fehler: konnte keine Instanz des %s-Moduls finde
 $lang['error_nomatchingmodules'] = 'Fehler: konnte keine &uuml;bereinstimmenden Module im Repository finden';
 $lang['error_nomodules'] = 'Fehler: konnte die Liste der installierten Module nicht abfragen';
 $lang['upgrade_available'] = 'Neuere Version verf&uuml;gbar (%s), Sie verwenden (%s)';
-$lang['newversions'] = 'Installierte Module';
-$lang['error_depends'] = 'Eines oder mehrere abh&auml;ngige Module, die f&uuml;r den Einsatz des gew&uuml;nschten Moduls ben&ouml;tigt werden, sind nicht installiert. Sie sollten diese daher zuerst installieren.';
-$lang['msg_nodependencies'] = 'F&uuml;r dieses Modul sind keine Abh&auml;ngigkeiten von anderen Modulen bekannt';
+$lang['newversions'] = 'Verf&uuml;gbare Aktualisierungen';
+$lang['error_depends'] = 'Eines oder mehrere abh&auml;ngige Module, die f&uuml;r den Einsatz des gew&uuml;nschten Moduls ben&ouml;tigt werden, sind nicht installiert. Sie sollten diese zuerst diese installieren.';
+$lang['msg_nodependencies'] = 'Dieses Modul hat keine Abh&auml;ngigkeiten von anderen Modulen.';
 $lang['dependstxt'] = 'Abh&auml;ngigkeiten';
 $lang['use_at_your_own_risk'] = 'Verwendung auf eigene Gefahr';
-$lang['compatibility_disclaimer'] = 'Die hier angezeigten Module wurden sowohl von CMSms-Entwicklern als auch Drittanbietern erstellt. Wir k&ouml;nnen nicht garantieren, dass jedes hier angebotene Modul mit Ihrem System funktionsf&auml;hig, getestet oder kompatibel ist. Vor der Installation sollten Sie daher die Modul-Hilfe und die Informationen/Postings im Forum lesen.';
+$lang['compatibility_disclaimer'] = 'Die hier angezeigten Module wurden sowohl von CMSms-Entwicklern als auch Drittanbietern erstellt. Wir k&ouml;nnen nicht garantieren, dass jedes hier angebotene Modul mit Ihrem System funktionsf&auml;hig, getestet oder kompatibel ist. Vor der Installation sollten Sie daher die Modulhilfe und die Informationen/Postings im Forum lesen.';
 $lang['notice'] = 'Hinweis';
 $lang['general_notice'] = 'Die hier angezeigte Version repr&auml;sentiert die jeweils letzte, im ausgew&auml;hlten Moduldepot (wahrscheinlich das CMS %s) als XML-Datei vorhandene Modulversion. Diese Version kann die letzte/aktuellste sein, muss aber nicht. Um dies zu pr&uuml;fen, k&ouml;nnen Sie sich die verf&uuml;gbaren Dateien im gew&auml;hlten Moduldepot anschauen. Wenn Sie das voreingestellte Moduldepot verwenden, k&ouml;nnen Sie im Suchfeld von <a href="http://dev.cmsmadesimple.org">forge</a> den Namen des Moduls eingeben und dann auf &quot;Files&quot; klicken.';
 $lang['incompatible'] = 'Inkompatibel';
@@ -42,7 +42,7 @@ $lang['availablemodules'] = 'Aktueller Status der im Depot verf&uuml;gbaren Modu
 $lang['helptxt'] = 'Hilfe';
 $lang['abouttxt'] = '&Uuml;ber';
 $lang['xmltext'] = 'XML-Datei';
-$lang['nametext'] = 'Modul-Name';
+$lang['nametext'] = 'Modulname';
 $lang['vertext'] = 'Version ';
 $lang['sizetext'] = 'Gr&ouml;&szlig;e (Kilobytes)';
 $lang['statustext'] = 'Status/Aktion';
@@ -111,9 +111,9 @@ $lang['help'] = '<h3>Was macht dieses Modul?</h3>
 <h3>Copyright und Lizenz</h3>
 <p>Copyright &copy; 2006, calguy1000 <a href="mailto:calguy1000@hotmail.com"><calguy1000@hotmail.com></a>. Alle Rechte vorbehalten.</p>
 <p>Dieses Modul wurde unter der <a href="http://www.gnu.org/licenses/licenses.html#GPL">GNU Public License</a> ver&ouml;ffentlicht. Sie m&uuml;ssen dieser Lizenz zustimmen, bevor Sie das Modul verwenden.</p>';
-$lang['qca'] = 'P0-617342851-1252404665837';
-$lang['utma'] = '156861353.343462282.1252405474.1252405474.1252408135.2';
-$lang['utmc'] = '156861353';
-$lang['utmz'] = '156861353.1252405474.1.1.utmccn=(referral)|utmcsr=forum.cmsmadesimple.org|utmcct=/index.php|utmcmd=referral';
+$lang['qca'] = 'P0-588183162-1266997281230';
+$lang['utma'] = '156861353.1691856853.1266999438.1266999438.1266999438.1';
 $lang['utmb'] = '156861353';
+$lang['utmc'] = '156861353';
+$lang['utmz'] = '156861353.1266999438.1.1.utmccn=(referral)|utmcsr=forum.cmsmadesimple.org|utmcct=/index.php|utmcmd=referral';
 ?>
\ No newline at end of file
