@@ -1,4 +1,12 @@
 <?php
+$lang['test_error_estrict'] = 'Le param&egrave;tre error_reporting pour assurer E_STRICT est d&eacute;sactiv&eacute;';
+$lang['test_estrict_failed'] = 'E_STRICT est activ&eacute;';
+$lang['info_estrict_failed'] = 'Certaines biblioth&egrave;ques que CMSMS utilise ne fonctionnent pas bien avec E_STRICT. Merci de d&eacute;sactiver avant de continuer';
+$lang['test_error_edeprecated'] = 'Le param&egrave;tre error_reporting pour assurer E_DEPRECATED est d&eacute;sactiv&eacute;';
+$lang['test_edeprecated_failed'] = 'E_DEPRECATED est activ&eacute;';
+$lang['info_edeprecated_failed'] = 'Si E_DEPRECATED est activ&eacute;, les utilisateurs verront de nombreux messages d&#039;avertissement qui pourraient affecter l&#039;affichage et le fonctionnement';
+$lang['invalidemail'] = 'L&#039;adresse email entr&eacute;e est invalide !';
+$lang['empty_query'] = 'Base de donn&eacute;es vide ?? %s';
 $lang['no_db_driver'] = 'Aucun driver de Base de Donn&eacute;es compatible CMSMS';
 $lang['test_check_output_buffering'] = 'V&eacute;rification des buffers de sortie';
 $lang['test_check_output_buffering_failed'] = 'Les buffers de sortie sont d&eacute;sactiv&eacute;s. Vous ne serez probablement pas en mesure d&#039;utiliser toutes les fonctionnalit&eacute;s de cette fonction';
@@ -8,43 +16,43 @@ $lang['test_check_tempnam'] = 'V&eacute;rification de la fonction PHP tempnam';
 $lang['test_check_db_drivers'] = 'Drivers de Base de Donn&eacute;es';
 $lang['test_check_db_drivers_failed'] = 'Aucun drivers DB trouv&eacute;';
 $lang['test_check_register_globals'] = 'V&eacute;rification PHP register globals';
-$lang['test_check_register_globals_failed'] = 'PHP register_globals actif. Pour des raisons de s&eacute;curit&eacute;, d&eacute;sactiver cette option.';
+$lang['test_check_register_globals_failed'] = 'PHP register_globals actif. Pour des raisons de s&eacute;curit&eacute;, d&eacute;sactivez cette option.';
 $lang['test_check_disable_functions'] = 'V&eacute;rification des fonctions PHP d&eacute;sactiv&eacute;es';
-$lang['test_check_disable_functions_failed'] = 'Attention : Ceci est une liste des fonctions d&eacute;sactiv&eacute;es sur votre serveur.';
+$lang['test_check_disable_functions_failed'] = 'Attention : ceci est une liste des fonctions d&eacute;sactiv&eacute;es sur votre serveur.';
 $lang['install_admin_db_port'] = 'Port de Base de Donn&eacute;es';
-$lang['install_admin_db_port_info'] = 'Laisser ce champ vide pour avoir le port de BD par d&eacute;faut';
+$lang['install_admin_db_port_info'] = 'Laissez ce champ vide pour avoir le port de BD par d&eacute;faut';
 $lang['install_admin_db_socket'] = 'Socket de Base de Donn&eacute;es';
 $lang['install_admin_db_socket_info'] = 'NON support&eacute;.';
-$lang['install_admin_frontendlang'] = 'Langue par d&eacute;faut pour le frontend. Locale &agrave; utiliser par d&eacute;faut pour diverses fonctions de manipulation de la date, etc... Laisser ce champ vide pour un environnement multilangue ou utiliser les valeurs par d&eacute;faut du serveur';
+$lang['install_admin_frontendlang'] = 'Langue par d&eacute;faut pour l&#039;interface publique. Locale &agrave; utiliser par d&eacute;faut pour diverses fonctions de manipulation de la date, etc... Laisser ce champ vide pour un environnement multilingue ou utiliser les valeurs par d&eacute;faut du serveur';
 $lang['install_default_encoding'] = 'Dans presque tous les cas, utf-8 devrait &ecirc;tre l&#039;encodage. Si vous vous voulez un encodage diff&eacute;rent, changez ici, mais gardez &agrave; l&#039;esprit, cependant, que toutes les traductions de langues sont en utf-8';
 $lang['installer_done'] = '[fait]';
 $lang['installer_failed'] = '[&eacute;chec]';
-$lang['create_permission'] = 'Cr&eacute;er autorisation ...';
+$lang['create_permission'] = 'Cr&eacute;ation des permissions ...';
 $lang['add_column_sql'] = 'Ajout de colonne &agrave; la table %s ...';
 $lang['update_table_sql'] = 'Mise &agrave; jour de la table %s ...';
 $lang['installing_module'] = 'Installation du module %s ...';
-$lang['updating_schema_version'] = 'Upgrade au sch&eacute;ma version %s ...';
-$lang['upgrade_config'] = 'Mise &agrave; jour du fichier config.php';
-$lang['upgrade_config_info'] = 'Mise &agrave; jour configuration';
-$lang['upgrade_failed_again'] = 'Une ou plusieurs mises &agrave; niveau ont &eacute;chou&eacute;es. Merci de corriger le probl&egrave;me, puis cliquez sur le bouton ci-dessous pour rev&eacute;rifier';
+$lang['updating_schema_version'] = 'Mise &agrave; jour au sch&eacute;ma version %s ...';
+$lang['upgrade_config'] = 'Mise &agrave; niveau du fichier config.php';
+$lang['upgrade_config_info'] = 'Mise &agrave; niveau de la configuration';
+$lang['upgrade_failed_again'] = 'Une ou plusieurs mises &agrave; niveau ont &eacute;chou&eacute;. Merci de corriger le probl&egrave;me, puis cliquez sur le bouton ci-dessous pour rev&eacute;rifier';
 $lang['upgrade_cache_dirs'] = 'Effacement des fichiers du dossier de cache';
 $lang['cannot_clean_cache_dirs'] = 'Impossible d&#039;effacer les fichiers du dossier de cache !';
 $lang['upgrade_schema'] = 'Upgrade du sch&eacute;ma version&nbsp;';
-$lang['need_upgrade_schema'] = 'CMSMS a besoin d&#039;une mise &agrave; jour.<br />Vous utilisez le sch&eacute;ma version %s et vous devez upgrader au sch&eacute;ma version %s';
+$lang['need_upgrade_schema'] = 'CMSMS a besoin d&#039;une mise &agrave; niveau.<br />Vous utilisez le sch&eacute;ma version %s et vous devez mettre &agrave; niveau vers le sch&eacute;ma version %s';
 $lang['schema_ok'] = 'Maintenant, la base de donn&eacute;es de CMS est &agrave; jour et utilise le sch&eacute;ma version %s';
 $lang['noneed_upgrade_schema'] = 'La base de donn&eacute;es de CMS est &agrave; jour et utilise le sch&eacute;ma version %s';
-$lang['upgrade_modules'] = 'Mise &agrave; jour des modules';
+$lang['upgrade_modules'] = 'Mise &agrave; niveau des modules';
 $lang['noneed_upgrade_modules'] = 'Les modules du noyau sont &agrave; jour';
-$lang['upgrade_sql_module_from_to'] = 'Upgrade SQL du module &quot;%s&quot; depuis %s vers %s ...';
-$lang['upgrade_event_module_from_to'] = 'Upgrade &eacute;v&eacute;nements du module &quot;%s&quot; depuis  %s vers %s ...';
+$lang['upgrade_sql_module_from_to'] = 'Mise &agrave; niveau SQL du module &quot;%s&quot; depuis %s vers %s ...';
+$lang['upgrade_event_module_from_to'] = 'Mise &agrave; niveau des &eacute;v&eacute;nements du module &quot;%s&quot; depuis  %s vers %s ...';
 $lang['sitedown_not_removed'] = 'Impossible de supprimer le fichier tmp/cache/SITEDOWN. Merci de le faire manuellement ou votre site affichera le message de maintenance.';
-$lang['upgrade_ok'] = 'V&eacute;rifier le fichier config.php, modifier &eacute;ventuellement la configuration et remettre les permissions &agrave; 444 pour des raisons de s&eacute;curit&eacute;. Vous pouvez aussi v&eacute;rifier si vos modules sont &agrave; la derni&egrave;re version, en allant au menu Extensions -> Modules et regarder si l&#039;indication &quot;Mise &agrave; jour n&eacute;cessaire&quot; existe.';
-$lang['upgrade_complete'] = 'Mise &agrave; jour termin&eacute;e';
+$lang['upgrade_ok'] = 'V&eacute;rifier le fichier config.php, modifier &eacute;ventuellement la configuration et remettre les permissions &agrave; 444 pour des raisons de s&eacute;curit&eacute;. Vous pouvez aussi v&eacute;rifier si vos modules sont &agrave; la derni&egrave;re version, en allant au menu Extensions -> Modules et regarder si l&#039;indication &quot;Mise &agrave; niveau n&eacute;cessaire&quot; existe.';
+$lang['upgrade_complete'] = 'Mise &agrave; niveau termin&eacute;e';
 $lang['upgrade_end'] = 'CMSMS est &agrave; jour. Cliquez %s pour aller sur votre site ou aller sur %s.';
 $lang['here'] = 'ici';
 $lang['go_to_admin'] = 'Administration';
 $lang['errorfilenot'] = 'Fichier non trouv&eacute; !';
-$lang['errorfilenotwritable'] = 'Le fichier n&#039;a pas de permissions en &eacute;criture';
+$lang['errorfilenotwritable'] = 'Le fichier n&#039;a pas de permission en &eacute;criture';
 $lang['nofiles'] = 'Cette ressource n&#039;existe pas !';
 $lang['is_directory'] = 'Cette ressource est un dossier !';
 $lang['is_readable_false'] = 'Cette ressource n&#039;a pas les permissions de lecture !';
@@ -65,11 +73,11 @@ $lang['function_file_uploads_off'] = 'file_uploads est d&eacute;sactiv&eacute; d
 $lang['upload_file_no_readable'] = 'Fichier upload&eacute; non lisible !';
 $lang['upload_file_multiple'] = 'Les uploads multiples ne sont pas autoris&eacute;s !';
 $lang['test_check_magic_quotes_gpc'] = 'V&eacute;rification de &quot;magic_quotes&quot; pour les op&eacute;rations Get/Post/Cookie';
-$lang['test_check_magic_quotes_gpc_failed'] = 'Lorsque les magic_quotes sont &agrave; &quot;On&quot;, les guillemets simples, doubles et antislash sont &eacute;chapp&eacute;s avec un antislash automatiquement. Vous pouvez avoir des probl&egrave;mes avec les gabarits.';
+$lang['test_check_magic_quotes_gpc_failed'] = 'Lorsque les &quot;magic_quotes&quot; sont &agrave; &quot;On&quot;, les guillemets simples, doubles et antislash sont &eacute;chapp&eacute;s avec un antislash automatiquement. Vous pouvez avoir des probl&egrave;mes avec les gabarits.';
 $lang['test_check_magic_quotes_runtime'] = 'V&eacute;rification de magic_quotes_runtime';
-$lang['test_check_magic_quotes_runtime_failed'] = 'Lorsque les magic_quotes sont &agrave; &quot;On&quot;, la plupart des fonctions qui retournent des donn&eacute;es externes, comme ceux des bases de donn&eacute;es ou des fichiers texte, auront &eacute;t&eacute; &eacute;chapp&eacute; avec un anti-slash. Vous pouvez avoir des probl&egrave;mes.';
+$lang['test_check_magic_quotes_runtime_failed'] = 'Lorsque les &quot;magic_quotes&quot; sont &agrave; &quot;On&quot;, la plupart des fonctions qui retournent des donn&eacute;es externes, comme ceux des bases de donn&eacute;es ou des fichiers texte, auront &eacute;t&eacute; &eacute;chapp&eacute; avec un anti-slash. Vous pouvez avoir des probl&egrave;mes avec CMS made simple.';
 $lang['install_admin_checksum'] = 'V&eacute;rification de votre installation';
-$lang['upgrade_admin_checksum'] = 'V&eacute;rification de votre installation avant mise &agrave; jour';
+$lang['upgrade_admin_checksum'] = 'V&eacute;rification de votre installation avant mise &agrave; niveau';
 $lang['checksum'] = 'Test de contr&ocirc;le (checksum)';
 $lang['checksum_file'] = 'Fichier de contr&ocirc;le (checksum)';
 $lang['install_test_checksum'] = 'Vous pouvez valider l&#039;int&eacute;grit&eacute; de vos fichiers CMSMS en comparant avec le fichier de contr&ocirc;le (cmsmadesimple-x.x.x-xxxx-checksum.dat). Il peut vous aider &agrave; trouver des probl&egrave;mes sur le transfert des fichiers.';
@@ -117,7 +125,7 @@ $lang['help_systeminformation'] = 'Les informations affich&eacute;es ci-dessous
 $lang['systeminfo'] = 'Informations syst&egrave;me';
 $lang['systeminfodescription'] = 'Affiche diff&eacute;rentes informations sur votre syst&egrave;me pour aider &agrave; diagnostiquer des probl&egrave;mes.';
 $lang['error'] = 'Erreur';
-$lang['new_version_available'] = '<em>Remarque :</em> Une nouvelle version de CMS Made Simple est disponible. Informez-en votre administrateur.';
+$lang['new_version_available'] = '<em>Remarque :</em> une nouvelle version de CMS Made Simple est disponible. Informez-en votre administrateur.';
 $lang['info_urlcheckversion'] = 'Si cette URL utilise le mot &quot;none&quot;, aucun contr&ocirc;le ne sera effectu&eacute;.<br/>Une cha&icirc;ne vide utilisera l&#039;URL par d&eacute;faut.';
 $lang['urlcheckversion'] = 'V&eacute;rifier les nouvelles versions CMS &agrave; l&#039;aide de cette URL&nbsp;';
 $lang['read'] = 'Lecture';
@@ -132,9 +140,9 @@ $lang['about'] = 'A propos';
 $lang['action'] = 'Action&nbsp;';
 $lang['actionstatus'] = 'Action/Statut';
 $lang['active'] = 'Actif';
-$lang['cantremove'] = 'Impossible de supprimer';
+$lang['cantremove'] = 'Suppression impossible';
 $lang['changepermissions'] = 'Changement de permissions';
-$lang['changepermissionsconfirm'] = 'Utiliser avec pr&eacute;caution\n\nCette action veillera &agrave; ce que tous les fichiers qui composent le module soit en &eacute;criture sur le serveur web.\n&Ecirc;tes vous s&ucirc;r de vouloir continuer ?';
+$lang['changepermissionsconfirm'] = 'Utiliser avec pr&eacute;caution\n\nCette action veillera &agrave; ce que tous les fichiers qui composent le module soit en &eacute;criture sur le serveur web.\n&Ecirc;tes vous s&ucirc;r(e) de vouloir continuer ?';
 $lang['success'] = 'Cr&eacute;ation r&eacute;ussie&nbsp;';
 $lang['advanced'] = 'Avanc&eacute;';
 $lang['back'] = 'Retour au Menu';
@@ -148,7 +156,7 @@ $lang['databasetype'] = 'Type de base de donn&eacute;es&nbsp;';
 $lang['date'] = 'Date&nbsp;';
 $lang['default'] = 'D&eacute;faut';
 $lang['delete'] = 'Supprimer';
-$lang['deleteconfirm'] = '&Ecirc;tes-vous s&ucirc;r de vouloir supprimer - %s - ?';
+$lang['deleteconfirm'] = '&Ecirc;tes-vous s&ucirc;r(e) de vouloir supprimer - %s - ?';
 $lang['description'] = 'Description&nbsp;';
 $lang['directoryexists'] = 'Ce dossier existe d&eacute;j&agrave;.';
 $lang['down'] = 'Bas';
@@ -156,8 +164,8 @@ $lang['edit'] = 'Editer';
 $lang['email'] = 'Addresse email';
 $lang['errordeletingfile'] = 'Impossible de supprimer le fichier. (probl&egrave;me de permissions ?)';
 $lang['errordirectorynotwritable'] = 'Aucune autorisation d&#039;&eacute;crire dans le dossier. Cela pourrait &ecirc;tre caus&eacute; par les permissions de fichiers. Le safe_mode de PHP peut causer des difficult&eacute;s.';
-$lang['cachenotwritable'] = 'Le dossier /tmp/cache n&#039;a pas de permissions en &eacute;criture. L&#039;effacement du cache ne fonctionnera pas. Mettre Le dossier /tmp/cache avec des droits de lecture/&eacute;criture/ex&eacute;cution (chmod 777). Il est &eacute;galement possible de devoir d&eacute;sactiver le safe_mode.';
-$lang['modulesnotwritable'] = 'Le dossier /modules n&#039;a pas de permissions en &eacute;criture. Si vous souhaitez installer des modules en t&eacute;l&eacute;chargeant un fichier XML, vous devez donner au dossier /modules des droits de lecture/ &eacute;criture/ex&eacute;cution (chmod 777). Le safe_mode de PHP peut causer des difficult&eacute;s.';
+$lang['cachenotwritable'] = 'Le dossier /tmp/cache n&#039;a pas de permissions en &eacute;criture. L&#039;effacement du cache ne fonctionnera pas. Mettre Le dossier /tmp/cache avec des droits de lecture/&eacute;criture/ex&eacute;cution (chmod 777 ou 755 ou 775 suivant h&eacute;bergement). Il est &eacute;galement possible de d&eacute;sactiver le safe_mode.';
+$lang['modulesnotwritable'] = 'Le dossier /modules n&#039;a pas de permissions en &eacute;criture. Si vous souhaitez installer des modules en t&eacute;l&eacute;chargeant un fichier XML, vous devez donner au dossier /modules des droits de lecture/ &eacute;criture/ex&eacute;cution (chmod 777 ou 755 ou 775 suivant h&eacute;bergement). Le safe_mode de PHP peut causer des difficult&eacute;s.';
 $lang['false'] = 'Faux';
 $lang['settrue'] = 'Mettre &agrave; Vrai';
 $lang['filename'] = 'Nom du fichier';
@@ -179,15 +187,15 @@ $lang['user'] = 'Utilisateur';
 $lang['userdefinedtags'] = 'Balises Utilisateurs';
 $lang['usermanagement'] = 'Management Utilisateurs';
 $lang['username'] = 'Nom d&#039;utilisateur ';
-$lang['usernameincorrect'] = 'Nom d&#039;utilisateur ou password incorrect';
+$lang['usernameincorrect'] = 'Nom d&#039;utilisateur ou mot de passe incorrect';
 $lang['version'] = 'Version&nbsp;';
-$lang['install_title'] = 'CMS Made Simple Installation (&eacute;tape %s)';
+$lang['install_title'] = 'Installation de CMS Made Simple (&eacute;tape %s)';
 $lang['install_system'] = 'Installation du Syst&egrave;me';
 $lang['install_thanks'] = 'Merci pour l&#039;installation de CMS Made Simple';
-$lang['upgrade_title'] = 'CMS Made Simple Mise &agrave; jour (&eacute;tape %s)';
-$lang['upgrade_system'] = 'Mise &agrave; jour du Syst&egrave;me';
-$lang['upgrade_thanks'] = 'Merci pour la mise &agrave; jour de CMS Made Simple vers';
-$lang['install_please_read'] = 'Merci de lire <a href="http://wiki.cmsmadesimple.org/index.php/User_Handbook/Installation/Troubleshooting/fr" target="_blank">R&eacute;solution de probl&egrave;mes durant l&#039;installation</a> du Wiki de CMS Made Simple.';
+$lang['upgrade_title'] = 'CMS Made Simple mise &agrave; niveau (&eacute;tape %s)';
+$lang['upgrade_system'] = 'Mise &agrave; niveau du syst&egrave;me';
+$lang['upgrade_thanks'] = 'Merci pour la mise &agrave; niveau de CMS Made Simple vers';
+$lang['install_please_read'] = 'Merci de lire <a rel="external" href="http://wiki.cmsmadesimple.org/index.php/User_Handbook/Installation/Troubleshooting/fr">R&eacute;solution de probl&egrave;mes durant l&#039;installation</a> du Wiki de CMS Made Simple.';
 $lang['install_checking'] = 'V&eacute;rification des permissions et de la configuration PHP';
 $lang['install_test'] = 'Test&nbsp;';
 $lang['install_result'] = 'R&eacute;sultat';
@@ -217,8 +225,8 @@ $lang['test_check_umask'] = 'R&eacute;sultat du test sur le fichier cr&eacute;&e
 $lang['test_umask_not_given'] = 'Umask Non donn&eacute;';
 $lang['test_check_umask_failed'] = 'Test Umask d&eacute;faillant';
 $lang['test_username_not_given'] = 'Nom d&#039;utilisateur non renseign&eacute; !';
-$lang['test_username_illegal'] = 'Le Nom d&#039;utilisateur contient des caract&egrave;res invalides !';
-$lang['test_not_both_passwd'] = 'Merci de renseigner les 2 champs Mot de passe !';
+$lang['test_username_illegal'] = 'Le nom d&#039;utilisateur contient des caract&egrave;res invalides !';
+$lang['test_not_both_passwd'] = 'Merci de renseigner les 2 champs &quot;mot de passe&quot; !';
 $lang['test_passwd_not_match'] = 'Mots de passe diff&eacute;rents !';
 $lang['test_email_accountinfo'] = 'Email information selectionn&eacute;, mais aucune adresse email renseign&eacute;e';
 $lang['test_database_prefix'] = 'Le pr&eacute;fixe des tables de Base de donn&eacute;es contient des caract&egrave;res invalides !';
@@ -229,7 +237,7 @@ $lang['test_could_not_create_table'] = 'Impossible de cr&eacute;er une table. V&
 $lang['test_check_php'] = 'V&eacute;rification version PHP %s+';
 $lang['test_min_recommend'] = '(mini %s, recommand&eacute; %s ou plus)';
 $lang['test_min_recommend_plus'] = '(mini %s, recommand&eacute;; %s+)';
-$lang['test_requires_php_version'] = 'CMS Made Simple a besoin de la version PHP 4.3 ou plus (vous avez %s), mais PHP %s ou plus est recommand&eacute; pour des probl&egrave;mes de compatibilit&eacute; avec les modules tierces parties';
+$lang['test_requires_php_version'] = 'CMS Made Simple a besoin de la version PHP 5.2.4 ou plus (vous avez %s), mais PHP %s ou plus est recommand&eacute; pour des probl&egrave;mes de compatibilit&eacute; avec les modules tierces parties';
 $lang['test_check_md5_func'] = 'V&eacute;rification de la fonction md5';
 $lang['test_check_safe_mode'] = 'V&eacute;rification de PHP safe_mode';
 $lang['test_check_safe_mode_failed'] = 'le safe_mode de PHP peut causer des difficult&eacute;s avec les fichiers upload&eacute;s et pour d&#039;autres fonctions. Tout d&eacute;pend de la fa&ccedil;on dont le serveur est configur&eacute;.';
@@ -246,7 +254,7 @@ $lang['test_check_xml_failed'] = 'le support XML n&#039;est pas compil&eacute; d
 $lang['test_allow_url_fopen_failed'] = 'Quand l&#039;autorisation &quot;url fopen&quot; est d&eacute;sactiv&eacute;e, vous ne serez pas en mesure d&#039;acc&eacute;der aux URL de fichiers en utilisant le protocole ftp ou http. ';
 $lang['test_remote_url'] = 'Test URL &agrave; distance';
 $lang['test_remote_url_failed'] = 'Vous ne serez probablement pas en mesure d&#039;ouvrir un fichier sur un serveur web distant.';
-$lang['connection_error'] = 'Les connexions http sortantes ne semblent pas fonctionner ! Un pare-feu ou un contr&ocirc;le d&#039;acc&egrave;s bloquerait les connexions externes ? Cela donnera un d&eacute;faut dans le module ModuleManager(Gestionnaire de Modules), et peut-&ecirc;tre dans d&#039;autres fonctions.';
+$lang['connection_error'] = 'Les connexions http sortantes ne semblent pas fonctionner ! Un pare-feu ou un contr&ocirc;le d&#039;acc&egrave;s bloquerait les connexions externes ? Cela donnera un d&eacute;faut dans le module ModuleManager (Gestionnaire de Modules), et peut-&ecirc;tre dans d&#039;autres fonctions.';
 $lang['remote_connection_timeout'] = 'D&eacute;lai de connexion &eacute;coul&eacute; !';
 $lang['search_string_find'] = 'Connection Ok !';
 $lang['connection_failed'] = 'Erreur de connection !';
@@ -275,52 +283,51 @@ $lang['test_check_session_save_path_failed'] = 'Votre session.save_path est &quo
 $lang['test_check_ini_set'] = 'V&eacute;rification si ini_set fonctionne';
 $lang['test_check_ini_set_failed'] = 'Bien que la capacit&eacute; de passer outre les param&egrave;tres de php ini n&#039;est pas obligatoire, certaines fonctionnalit&eacute;s de module (facultatif) utilisent ini_set pour proroger des d&eacute;lais d&#039;expiration, et pour permettre le t&eacute;l&eacute;chargement de fichiers volumineux, etc. Vous pouvez avoir des difficult&eacute;s avec certaines fonctionnalit&eacute;s sans cette possibilit&eacute;. Ce test peut &eacute;chouer si le safe_mode est activ&eacute; (voir ci-dessous).';
 $lang['install_admin_header'] = 'Information sur le compte administrateur';
-$lang['install_admin_info'] = 'Choisissez le nom d&#039;utilisateur, l&#039;adresse email et le mot de passe pour votre compte d&#039;administration. Veuillez vous assurer que vous enregistrez ces donn&eacute;es &quot;quelque part&quot;, car elles sont indispensables pour l&#039;acc&egrave;s &agrave; votre syst&egrave;me d&#039;administration de CMS Made Simple.';
+$lang['install_admin_info'] = 'Choisissez le nom d&#039;utilisateur, le mot de passe et l&#039;adresse email pour votre compte d&#039;administration. Veuillez vous assurer que vous enregistrez ces donn&eacute;es &quot;quelque part&quot;, car elles sont indispensables pour l&#039;acc&egrave;s &agrave; votre syst&egrave;me d&#039;administration de CMS Made Simple.';
 $lang['install_admin_email'] = 'Adresse email';
 $lang['install_admin_email_info'] = 'Email pour le compte administrateur';
 $lang['install_admin_email_note'] = '<strong>Remarque :</strong> Cette notification utilise la fonction PHP Mail. Si vous ne recevez pas cet email, cela peut &ecirc;tre une indication de mauvaise configuration de votre serveur et vous devriez contacter votre h&eacute;bergeur.';
-$lang['install_admin_sitename'] = 'C&#039;est le nom de votre site. Il sera employ&eacute; dans divers endroits des gabarits par d&eacute;faut et peut &ecirc;tre employ&eacute; n&#039;importe o&ugrave; avec la Balise (Tag) {sitename}.';
+$lang['install_admin_sitename'] = 'C&#039;est le nom de votre site WEB. Il sera employ&eacute; dans divers endroits des gabarits par d&eacute;faut et peut &ecirc;tre employ&eacute; n&#039;importe o&ugrave; avec la Balise (Tag) {sitename}.';
 $lang['install_admin_db'] = 'Information sur la base de donn&eacute;es';
-$lang['install_admin_db_info'] = '<p>Assurez vous d&#039;avoir cr&eacute;er votre base de donn&eacute;es et d&#039;avoir accord&eacute; les privil&egrave;ges &agrave; un utilisateur pour l&#039;utilisation de la base de donn&eacute;es (suivant les h&eacute;bergements).</p>
-<p>Pour MySQL, employez ce qui suit :</p>
-<p>Connectez-vous &agrave; MySQL depuis une console puis tapez les commandes suivantes :</p>
-<ol>
-<li>create database cms; (Utiliser le nom que vous voulez, sauf contrainte h&eacute;bergeur, mais retenez le nom exact)</li>
-<li>grant all privileges on cms.* to cms_user@localhost identified by &#039;cms_pass&#039;;</li>
-</ol>';
+$lang['install_admin_db_info'] = '<p><strong>Connectez-vous &agrave; MySQL depuis une console puis tapez les commandes suivantes :</strong><br />
+- create database cms; 
+(Utiliser le nom que vous voulez, sauf contrainte h&eacute;bergeur, mais retenez le nom exact)<br />
+- grant all privileges on cms.* to cms_user@localhost identified by &#039;cms_pass&#039;;<br />
+</p>
+<p><strong>Ou utiliser un programme comme PhpMyAdmin ou le panneau d&#039;administration de votre compte.</strong></p>';
 $lang['install_admin_follow'] = 'Merci de compl&eacute;ter les champs suivants&nbsp;';
 $lang['install_admin_db_type'] = 'Type de base de donn&eacute;es';
-$lang['install_admin_no_db'] = 'Il n&#039;existe pas de base de donn&eacute;es valide compil&eacute;e dans votre installation de PHP. Merci de confirmer que vous avez mysql, mysqli, et/ou postgres7 d&#039;install&eacute;, et essayer &agrave; nouveau.';
+$lang['install_admin_no_db'] = 'Il n&#039;existe pas de drivers de base de donn&eacute;es valide compil&eacute;e dans votre installation de PHP. Merci de confirmer que vous avez mysql, mysqli, et/ou postgres7 d&#039;install&eacute;, et essayez &agrave; nouveau.';
 $lang['install_admin_db_host'] = 'Adresse du serveur de base de donn&eacute;es';
 $lang['install_admin_db_name'] = 'Nom de la base de donn&eacute;es';
-$lang['install_admin_db_create'] = 'Cr&eacute;ation des tables - Ne pas cocher si mise &agrave; jour <br />(Attention : Suppression des donn&eacute;es existantes)';
+$lang['install_admin_db_create'] = 'Cr&eacute;ation des tables - Ne pas cocher si mise &agrave; niveau <br />(Attention : suppression des donn&eacute;es existantes)';
 $lang['install_admin_db_prefix'] = 'Pr&eacute;fixe des tables';
 $lang['install_admin_db_sample'] = 'Installer les exemples de contenus et les gabarits';
 $lang['retry'] = 'Nouvel essai';
 $lang['install_admin_db_create_seq'] = 'Cr&eacute;ation %s s&eacute;quences des tables ...&nbsp;';
-$lang['install_admin_importing'] = 'Import de sample data ...&nbsp;';
+$lang['install_admin_importing'] = 'Import des exemples de donn&eacute;es ...&nbsp;';
 $lang['invalid_query'] = 'Requ&ecirc;te invalide : %s';
 $lang['install_creating_table'] = '<p>Cr&eacute;ation table %s ... [%s]</p>';
-$lang['install_creating_index'] = '<p>Cr&eacute;ation index de table %s  ... [%s]</p ';
+$lang['install_creating_index'] = '<p>Cr&eacute;ation index de table %s  ... [%s]</p>';
 $lang['done'] = 'fait';
 $lang['failed'] = '&eacute;chec';
 $lang['install_admin_error_schema'] = 'Erreur dans le sch&eacute;ma SQL';
 $lang['install_admin_set_account'] = 'Configuration des informations administration ...&nbsp;';
 $lang['install_admin_set_sitename'] = 'Configuration du nom de votre Site ...&nbsp;';
-$lang['install_admin_setup'] = 'Continuez maintenant l&#039;installation de votre fichier de configuration, avec les donn&eacute;es recueillies. Quand vous &ecirc;tes pr&ecirc;t, cliquer sur le bouton Continuer.';
-$lang['install_admin_docroot'] = 'La racine de CMS (Adresse du site web)';
-$lang['install_admin_docroot_path'] = 'Chemin de la racine de CMS';
-$lang['install_admin_querystring'] = 'Symbole apr&egrave;s &quot;index.php?&quot; (exemple. http://www.mysite.com/index.php?page=xxx ). Laisser tel quel et &eacute;ventuellement &eacute;diter le fichier config.php &agrave; la main';
-$lang['invalid_querys'] = '<b>ATTENTION<b/> : Requ&ecirc;te invalide sur la base de donn&eacute;es !';
+$lang['install_admin_setup'] = 'Continuez maintenant l&#039;installation de votre fichier de configuration, avec les donn&eacute;es recueillies. Quand vous &ecirc;tes pr&ecirc;t, cliquez sur le bouton Continuer.';
+$lang['install_admin_docroot'] = 'La racine du CMS (adresse du site web)';
+$lang['install_admin_docroot_path'] = 'Chemin de la racine du CMS';
+$lang['install_admin_querystring'] = 'Symbole apr&egrave;s &quot;index.php?&quot; (exemple. http://www.monsite.fr/index.php?page=xxx ). Laissez tel quel et &eacute;ventuellement &eacute;ditez le fichier config.php &agrave; la main';
+$lang['invalid_querys'] = '<b>ATTENTION<b/> : requ&ecirc;te invalide sur la base de donn&eacute;es !';
 $lang['install_admin_sitedown'] = 'Erreur : Impossible de supprimer le fichier tmp/cache/SITEDOWN. Merci de le supprimer manuellement.';
 $lang['install_admin_update_hierarchy'] = 'Mise &agrave; jour de la hi&eacute;rarchie ...&nbsp;';
 $lang['install_admin_set_core_event'] = 'Configuration du noyau CMS Made Simple ...&nbsp;';
 $lang['install_admin_install_modules'] = 'Installation des modules ...&nbsp;';
 $lang['install_admin_index_search'] = 'Recherche de l&#039;index...&nbsp;';
-$lang['install_admin_clear_cache'] = 'Effacement du cache (Si besoin) ...&nbsp;';
+$lang['install_admin_clear_cache'] = 'Effacement du cache (si besoin) ...&nbsp;';
 $lang['install_admin_emailing'] = 'Mail d&#039;information sur le compte Administrateur cr&eacute;&eacute; ...&nbsp;';
 $lang['install_admin_congratulations'] = 'Merci pour l&#039;installation de CMS Made Simple, la configuration est termin&eacute;e - Se connecter sur&nbsp; ';
-$lang['could_not_connect_db'] = 'Impossible de se connecter &agrave; la base de donn&eacute;es. V&eacute;rifier que le Nom d&#039;utilisateur et/ou le mot de passe soit correct, et que les acc&egrave;s soit autoris&eacute;s pour l&#039;utilisateur.';
+$lang['could_not_connect_db'] = 'Impossible de se connecter &agrave; la base de donn&eacute;es. V&eacute;rifiez que le nom d&#039;utilisateur et/ou le mot de passe sont correct, et que les acc&egrave;s sont autoris&eacute;s pour l&#039;utilisateur.';
 $lang['cannot_write_config'] = 'Erreur : Impossible d&#039;&eacute;crire sur %s.';
 $lang['email_accountinfo_subject'] = 'CMS Made Simple - Information sur le compte administrateur';
 $lang['email_accountinfo_message'] = 'Merci d&#039;avoir install&eacute; CMS Made Simple.
@@ -330,8 +337,9 @@ Nom utilisateur : %s
 Mot de passe : %s
 
 Se connecter &agrave; l&#039;administration : %s';
-$lang['utma'] = '156861353.89360749.1215357409.1228149673.1229859907.64';
-$lang['utmz'] = '156861353.1228149673.63.38.utmcsr=apa-sante.fr|utmccn=(referral)|utmcmd=referral|utmcct=/page/index.php';
-$lang['utmb'] = '156861353.1.10.1229859907';
+$lang['qca'] = 'P0-1624099198-1262715852421';
+$lang['utma'] = '156861353.1979401837.1271056235.1271056235.1271056235.1';
 $lang['utmc'] = '156861353';
+$lang['utmz'] = '156861353.1271056235.1.1.utmccn=(direct)|utmcsr=(direct)|utmcmd=(none)';
+$lang['utmb'] = '156861353';
 ?>
\ No newline at end of file
