@@ -1,4 +1,6 @@
 <?php
+$lang['invalidemail'] = 'E-mailov&aacute; adresa je nespr&aacute;vna';
+$lang['empty_query'] = 'Pr&aacute;zdny dotaz?? %s';
 $lang['no_db_driver'] = 'Neboli n&aacute;jdene  žiadne kompatibiln&eacute; ovl&aacute;dače pre datab&aacute;zu';
 $lang['test_check_output_buffering'] = 'Kontrolujem output buffering';
 $lang['test_check_output_buffering_failed'] = 'Output buffering je vypnut&yacute;. Pravdepodobne nebude můcř využ&iacute;vař niektor&eacute; z funkcional&iacute;t, ktor&eacute; vyžad&uacute; Output buffering zapnut&yacute;';
@@ -79,10 +81,10 @@ $lang['test_check_open_basedir'] = 'Kontrola PHP Open Basedir';
 $lang['test_check_open_basedir_failed'] = 'Open basedir obmedzenia s&uacute; nastaven&eacute;. M&ocirc;žete mať probl&eacute;m s niektor&yacute;m vybran&yacute;mi funkcionalitami.';
 $lang['unlimited'] = 'Neobmedzene';
 $lang['test_open_basedir_session_save_path'] = 'Open basedir restrictions appear to be in effect. If you have SESSION problems and ini_set works, you can try to enable session by cookies adding: ini_set(&#039;session.use_only_cookies&#039;, 1);  to top of include.php';
-$lang['install_warn_db_createtables'] = 'Normally this field should be checked at all times.  Use caution when disabling this feature';
+$lang['install_warn_db_createtables'] = 'Zvyčajne b&yacute;va toto pole vždy kontrolovan&eacute;.  Buďte  opatrn&yacute; pri vypnut&iacute;';
 $lang['install_admin_tablesnotcreated'] = 'Process complete.  The installation process has completed, at your request database tables were not created.  However, the config file has been reset and all pre-installation tests have passed.  Thank you, and here is your';
 $lang['info_create_dir_and_file'] = 'The HTTP Process owner cannot create a file inside a directory that it owns. This probably means that safe mode is enabled in some way.  Many functions inside CMS made simple will not operate properly without this ability. Continuing is not possible.';
-$lang['test_create_dir_and_file'] = 'Checking if the httpd process can create a file inside of a directory it created.';
+$lang['test_create_dir_and_file'] = 'Kontrola, či  httpd process  m&ocirc;že vytvoriť s&uacute;bor vo vytvorenom adres&aacute;ri. ';
 $lang['cms_site'] = 'CMS str&aacute;nka';
 $lang['or_greater'] = 'Alebo v&auml;č&scaron;&iacute;';
 $lang['sitename'] = 'N&aacute;zov str&aacute;nky';
@@ -195,7 +197,7 @@ $lang['install_required_settings'] = 'Vyžadovan&eacute; nastavenia';
 $lang['install_recommended_settings'] = 'Doporučen&eacute; nastavenia';
 $lang['install_you_have'] = 'Vy m&aacute;te';
 $lang['install_legend'] = 'Legenda';
-$lang['install_symbol'] = 'Symbol';
+$lang['install_symbol'] = 'Znak';
 $lang['install_definition'] = 'Defin&iacute;cia';
 $lang['install_value_passed'] = 'Test v poriadku';
 $lang['install_value_failed'] = 'Test s chybami/chybou';
@@ -234,25 +236,25 @@ $lang['test_check_md5_func'] = 'Kontrola pre funkciu md5 ';
 $lang['test_check_safe_mode'] = 'Kontrola pre safe m&oacute;d';
 $lang['test_check_safe_mode_failed'] = 'Zapnut&yacute; PHP safe m&oacute;d  m&ocirc;že sp&ocirc;sobiť nejak&eacute; probl&eacute;my s nahr&aacute;van&iacute;tm s&uacute;borov a spr&aacute;vnym behom niektor&yacute;ch funkcional&iacute;t. V&scaron;etko z&aacute;vis&yacute; ako striktn&eacute; je nastaven&yacute; server pri zapnutom Safe m&oacute;de.';
 $lang['test_check_tokenizer'] = 'Kontroluje tokenizer funkcie';
-$lang['test_check_tokenizer_failed'] = 'Not having the tokenizer could cause pages to render as purely white. We required you have this installed.';
+$lang['test_check_tokenizer_failed'] = 'Bielu str&aacute;nku m&ocirc;že sp&ocirc;sobovať vypnut&aacute; funkcia Tokenizer. Požiadajte administr&aacute;tora o jej zapnutie';
 $lang['test_check_gd'] = 'Kontrola knižnice GD';
 $lang['test_check_gd_failed'] = 'GD knižnica je nevyhnutn&aacute; pre niektor&eacute; moduly a funkcionality';
 $lang['test_check_write'] = 'Kontrola pr&aacute;v pre zapisovanie na';
-$lang['test_may_not_exist'] = 'This file may not exist yet. If it does not, you should create an empty file with this name. Please also ensure that this file writable by the web server process.';
-$lang['could_not_retrieve_a_value'] = 'Could not retrieve a value.... passing anyways.';
-$lang['displaying_the_value_originally'] = '<br />Displaying the value originally set in the config file (this may not be accurate).';
+$lang['test_may_not_exist'] = 'S&uacute;bor možno e&scaron;te neexistujte. Ak tomu tak je, m&ocirc;žete vytvoriť pr&aacute;zdny s&uacute;bor s t&yacute;mto menom. Takisto sa uistite, že m&aacute; nastaven&eacute; pr&aacute;va na č&iacute;tanie. ';
+$lang['could_not_retrieve_a_value'] = 'Nepodarilo sa z&iacute;skať hodnotu';
+$lang['displaying_the_value_originally'] = '<br />Zobrazovanie nastaven&iacute; z configuračn&eacute;ho s&uacute;boru (nemus&iacute; byť presn&eacute;)';
 $lang['test_check_xml_func'] = 'Kontrola z&aacute;kladne podpory pre XML (expat)';
 $lang['test_check_xml_failed'] = 'XML support is not compiled into your php install. You can still use the system, but will not be able to use any of the remote module installation functions.';
 $lang['test_allow_url_fopen_failed'] = 'When allow url fopen is disabled you will not be able to accessing URL object like file using the ftp or http protocol.';
 $lang['test_remote_url'] = 'Test vzdialenej URL';
-$lang['test_remote_url_failed'] = 'You will probably not be able to open a file on a remote web server.';
+$lang['test_remote_url_failed'] = 'Pravdepodobne nebude m&ocirc;žno otvoriť s&uacute;bor cez vzdialen&yacute; web server. ';
 $lang['connection_error'] = 'Outgoing http connections do not appear to work! There is a firewall or some ACL for external connections?. This will result in module manager, and potentially other functionality failing.';
 $lang['remote_connection_timeout'] = 'Vypr&scaron;al časov&yacute; limit pripojenia!';
 $lang['search_string_find'] = 'Pripojenie v poriadku!';
 $lang['connection_failed'] = 'Pripojenie zlyhalo!';
-$lang['remote_response_ok'] = 'Remote response: ok!';
-$lang['remote_response_404'] = 'Remote response: not found!';
-$lang['remote_response_error'] = 'Remote response: error!';
+$lang['remote_response_ok'] = 'Vzdialen&aacute; odpoveď: ok!';
+$lang['remote_response_404'] = 'Vzdialen&aacute; odpoved: nen&aacute;jedn&eacute;!';
+$lang['remote_response_error'] = 'Vzdialen&aacute; odpoveď: chyba!';
 $lang['test_check_file_upload'] = 'Kontroluje nahr&aacute;vanie s&uacute;borov';
 $lang['test_check_file_failed'] = 'When file uploads are disabled you will not be able to use any of the file uploading facilities included in CMS Made Simple. If possible, this restriction should be lifted by your system admin to properly use all file management features of the system. Proceed with caution.';
 $lang['test_check_memory'] = 'Kontrolujem PHP limit pam&auml;te';
@@ -325,13 +327,14 @@ $lang['cannot_write_config'] = 'Chyba: Nem&ocirc;žem zapisovať do %s.';
 $lang['email_accountinfo_subject'] = 'Inform&aacute;cie o vytvorenom pr&iacute;stupe pre CMS Made Simple';
 $lang['email_accountinfo_message'] = 'Ďakuje za nain&scaron;talovanie syst&eacute;mu CMS Made Simple.
 
-Toto ja Va&scaron;e nov&eacute;už&iacute;vateľsk&eacute; konto:
+Toto ja Va&scaron;e nov&eacute; už&iacute;vateľsk&eacute; konto:
 už&iacute;vateľsk&eacute; meno: %s
 heslo: %s
 
 Prihl&aacute;ste sa pre administr&aacute;ciu str&aacute;nky: %s';
-$lang['utmz'] = '156861353.1230037831.636.39.utmcsr=dev.cmsmadesimple.org|utmccn=(referral)|utmcmd=referral|utmcct=/';
-$lang['utma'] = '156861353.4300742689275601400.1213256953.1229960270.1230037831.636';
+$lang['utma'] = '156861353.1262346118.1255805318.1257599213.1257604175.18';
+$lang['utmz'] = '156861353.1257604175.18.17.utmcsr=dev.cmsmadesimple.org|utmccn=(referral)|utmcmd=referral|utmcct=/';
+$lang['qca'] = 'P0-1154349044-1255805318049';
 $lang['utmc'] = '156861353';
-$lang['utmb'] = '156861353.7.10.1230037831';
+$lang['utmb'] = '156861353.1.10.1257604175';
 ?>
\ No newline at end of file
