@@ -16,7 +16,7 @@
 #along with this program; if not, write to the Free Software
 #Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
-#$Id: class.admintheme.inc.php 5774 2009-06-07 16:08:12Z calguy1000 $
+#$Id: class.admintheme.inc.php 6198 2010-04-09 18:45:16Z calguy1000 $
 
 /**
  * Class for Admin Theme
@@ -106,6 +106,11 @@ class AdminTheme
      */
     var $_notificationitems;
 
+    /**
+     * View Site URL
+     */
+    protected $_viewsite_url;
+
 	/**
 	 * Generic constructor.  Runs the SetInitialValues fuction.
 	 */
@@ -119,6 +124,12 @@ class AdminTheme
 	 */
 	function SetInitialValues($cms, $userid, $themeName)
 	{
+	  global $gCms;
+	  $contentops = $gCms->GetContentOperations();
+	  $dflt_content_id = $contentops->GetDefaultContent();
+	  $content_obj = $contentops->LoadContentFromId($dflt_content_id);
+	  $this->_viewsite_url = $content_obj->GetURL();
+
 		$this->title = '';
 		$this->subtitle = '';
 		$this->cms = $cms;
@@ -133,13 +144,13 @@ class AdminTheme
 		  {
 		  $this->query = 'module='.$_POST['module'];
 		  }
-        $this->userid = $userid;
+		$this->userid = $userid;
 		$this->themeName = $themeName;
 		$this->perms = array();
 		$this->recent = array();
 		$this->menuItems = array();
 		$this->breadcrumbs = array();
-        $this->imageLink = array();
+		$this->imageLink = array();
 		$this->modulesBySection = array();
 		$this->sectionCount = array();
         $this->SetModuleAdminInterfaces();
