@@ -17,7 +17,7 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
-#$Id: class.content.inc.php 5385 2009-01-05 19:35:18Z calguy1000 $
+#$Id: class.content.inc.php 6249 2010-04-23 17:55:50Z calguy1000 $
 
 /**
  * Generic content class.
@@ -29,7 +29,7 @@
  * @since		0.8
  * @package		CMS
  */
-
+define('CMS_CONTENT_HIDDEN_NAME','--------');
 class ContentBase
 {
     /**
@@ -141,6 +141,11 @@ class ContentBase
      */
     var $mCachable;
 
+    /**
+     * Secure?
+     */
+    var $mSecure;
+
     /**
      * Does this content have a preview function?
      */
@@ -181,6 +186,11 @@ class ContentBase
     var $mAdditionalEditors;
 	
     var $mReadyForEdit;
+
+    var $_attributes;
+    var $_prop_defaults;
+    var $_add_mode;
+
     /************************************************************************/
     /* Constructor related													*/
     /************************************************************************/
@@ -208,7 +218,7 @@ class ContentBase
 	$this->mType           = strtolower(get_class($this)) ;
 	$this->mOwner          = -1 ;
 	$this->mProperties     = new ContentProperties();
-	$this->mParentId       = -1 ;
+	$this->mParentId       = -2 ;
 	$this->mOldParentId    = -1 ;
 	$this->mTemplateId     = -1 ;
 	$this->mItemOrder      = -1 ;
@@ -225,6 +235,7 @@ class ContentBase
 	$this->mDefaultContent = false ;
 	$this->mShowInMenu     = false ;
 	$this->mCachable       = true;
+	$this->mSecure         = 0;
 	$this->mMenuText       = "" ;
 	$this->mCreationDate   = "" ;
 	$this->mModifiedDate   = "" ;
@@ -240,6 +251,26 @@ class ContentBase
      */
     function SetProperties()
     {
+      $this->AddContentProperty('target',10);
+      $this->AddBaseProperty('title',1,1);
+      $this->AddBaseProperty('menutext',2,1);
+      $this->AddBaseProperty('parent',3,1);
+      $this->AddBaseProperty('active',5);
+      $this->AddBaseProperty('showinmenu',5);
+      $this->AddBaseProperty('secure',6);
+      $this->AddBaseProperty('cachable',7);
+      $this->AddBaseProperty('alias',10);
+      $this->AddBaseProperty('titleattribute',55);
+      $this->AddBaseProperty('accesskey',56);
+      $this->AddBaseProperty('tabindex',57);
+      $this->AddBaseProperty('owner',90);
+      $this->AddBaseProperty('additionaleditors',91);
+
+      $this->AddContentProperty('image',50);
+      $this->AddContentProperty('thumbnail',50);
+      $this->AddContentProperty('extra1',80);
+      $this->AddContentProperty('extra2',81);
+      $this->AddContentProperty('extra3',82);
     }
 
     
@@ -327,6 +358,14 @@ class ContentBase
 	return $this->mMetadata;
     }
 
+    /**
+     * Content object handles the alias
+     */
+    function HandlesAlias()
+    {
+      return false;
+    }
+
     function SetMetadata($metadata)
     {
 	$this->DoReadyForEdit();
@@ -461,12 +500,14 @@ class ContentBase
 	return $this->mIdHierarchy;
     }
 
+
     function SetIdHierarchy($idhierarchy)
     {
 	$this->DoReadyForEdit();
 	$this->mIdHierarchy = $idhierarchy;
     }
 
+
     /**
      * Returns the Hierarchy
      */
@@ -475,12 +516,14 @@ class ContentBase
 	return $this->mHierarchyPath;
     }
 
+
     function SetHierarchyPath($hierarchypath)
     {
 	$this->DoReadyForEdit();
 	$this->mHierarchyPath = $hierarchypath;
     }
 
+
     /**
      * Returns the Active state
      */
@@ -489,12 +532,14 @@ class ContentBase
 	return $this->mActive;
     }
 
+
     function SetActive($active)
     {
 	$this->DoReadyForEdit();
 	$this->mActive = $active;
     }
 
+
     /**
      * Returns whether it should show in the menu
      */
@@ -503,12 +548,14 @@ class ContentBase
 	return $this->mShowInMenu;
     }
 
+
     function SetShowInMenu($showinmenu)
     {
         $this->DoReadyForEdit();
 	$this->mShowInMenu = $showinmenu;
     }
 
+
     /**
      * Returns if the page is the default
      */
@@ -517,22 +564,38 @@ class ContentBase
 	return $this->mDefaultContent;
     }
 
+
     function SetDefaultContent($defaultcontent)
     {
 	$this->DoReadyForEdit();
 	$this->mDefaultContent = $defaultcontent;
     }
 
+
     function Cachable()
     {
 	return $this->mCachable;
     }
 
+
     function SetCachable($cachable)
     {
 	$this->DoReadyForEdit();
 	$this->mCachable = $cachable;
     }
+
+
+    function Secure()
+    {
+      return $this->mSecure;
+    }
+
+
+    function SetSecure($secure)
+    {
+	$this->DoReadyForEdit();
+	$this->mSecure = $secure;
+    }
 	
 	function Markup()
 	{
@@ -555,8 +618,18 @@ class ContentBase
 		$this->DoReadyForEdit();
 		$this->mLastModifiedBy = $lastmodifiedby;
 	}
-	
-	function SetAlias($alias)
+
+	function RequiresAlias()
+	{
+	  return TRUE;
+	}
+
+	function IsViewable()
+	{
+	  return TRUE;
+	}
+
+	function SetAlias($alias, $doAutoAliasIfEnabled = true)
 	{
 		$this->DoReadyForEdit();
 		global $gCms;
@@ -564,7 +637,7 @@ class ContentBase
 
 		$tolower = false;
 
-		if ($alias == '' && $config['auto_alias_content'] == true)
+		if ($alias == '' && $doAutoAliasIfEnabled && $config['auto_alias_content'] == true)
 		{
 			$alias = trim($this->mMenuText);
 			if ($alias == '')
@@ -574,6 +647,11 @@ class ContentBase
 			
 			$tolower = true;
 			$alias = munge_string_to_url($alias, $tolower);
+// 			if( empty($alias) )
+// 			  {
+// 			    // calguy: quick hack so that the alias is never empty...
+// 			    $alias = 'alias';
+// 			  }
 			// Make sure auto-generated new alias is not already in use on a different page, if it does, add "-2" to the alias
 			$contentops =& $gCms->GetContentOperations();
 			$error = $contentops->CheckAliasError($alias);
@@ -680,10 +758,6 @@ class ContentBase
 	return true;
     }
 
-    function GetAdditionalContentBlocks()
-    {
-    }
-
     /**
      * Should this link be used in various places where a link is the only
      * useful output?  (Like next/previous links in cms_selflink, for example)
@@ -701,6 +775,11 @@ class ContentBase
       return FALSE;
     }
 
+	function IsSystemPage()
+	{
+		return FALSE;
+	}
+
     /************************************************************************/
     /* The rest																*/
     /************************************************************************/
@@ -772,6 +851,7 @@ class ContentBase
 				$this->mDefaultContent             = ($row->fields["default_content"] == 1 ? true : false);
 				$this->mShowInMenu                 = ($row->fields["show_in_menu"] == 1    ? true : false);
 				$this->mCachable                   = ($row->fields["cachable"] == 1        ? true : false);
+				$this->mSecure                     = $row->fields['secure'];
 				$this->mLastModifiedBy             = $row->fields["last_modified_by"];
 				$this->mCreationDate               = $row->fields["create_date"];
 				$this->mModifiedDate               = $row->fields["modified_date"];
@@ -840,7 +920,7 @@ class ContentBase
      * @returns	bool		If it fails, the object comes back to initial values and returns FALSE
      *				If everything goes well, it returns TRUE
      */
-	function LoadFromData($data, $loadProperties = false)
+	function LoadFromData(&$data, $loadProperties = false)
 	{
 	  global $gCms, $debug_errors;
 	  $config =& $gCms->GetConfig();
@@ -873,6 +953,7 @@ class ContentBase
 		$this->mActive                     = ($data["active"] == 1          ? true : false);
 		$this->mShowInMenu                 = ($data["show_in_menu"] == 1    ? true : false);
 		$this->mCachable                   = ($data["cachable"] == 1        ? true : false);
+		$this->mSecure                     = $data["secure"];
 		$this->mLastModifiedBy             = $data["last_modified_by"];
 		$this->mCreationDate               = $data["create_date"];
 		$this->mModifiedDate               = $data["modified_date"];
@@ -1002,7 +1083,7 @@ class ContentBase
 
 		$this->mModifiedDate = trim($db->DBTimeStamp(time()), "'");
 
-		$query = "UPDATE ".cms_db_prefix()."content SET content_name = ?, owner_id = ?, type = ?, template_id = ?, parent_id = ?, active = ?, default_content = ?, show_in_menu = ?, cachable = ?, menu_text = ?, content_alias = ?, metadata = ?, titleattribute = ?, accesskey = ?, tabindex = ?, modified_date = ?, item_order = ?, markup = ?, last_modified_by = ? WHERE content_id = ?";
+		$query = "UPDATE ".cms_db_prefix()."content SET content_name = ?, owner_id = ?, type = ?, template_id = ?, parent_id = ?, active = ?, default_content = ?, show_in_menu = ?, cachable = ?, secure = ?, menu_text = ?, content_alias = ?, metadata = ?, titleattribute = ?, accesskey = ?, tabindex = ?, modified_date = ?, item_order = ?, markup = ?, last_modified_by = ? WHERE content_id = ?";
 		$dbresult = $db->Execute($query, array(
 			$this->mName,
 			$this->mOwner,
@@ -1013,6 +1094,7 @@ class ContentBase
 			($this->mDefaultContent == true ? 1 : 0),
 			($this->mShowInMenu == true     ? 1 : 0),
 			($this->mCachable == true       ? 1 : 0),
+			$this->mSecure,
 			$this->mMenuText,
 			$this->mAlias,
 			$this->mMetadata,
@@ -1112,7 +1194,7 @@ class ContentBase
 
 		$this->mModifiedDate = $this->mCreationDate = trim($db->DBTimeStamp(time()), "'");
 
-		$query = "INSERT INTO ".$config["db_prefix"]."content (content_id, content_name, content_alias, type, owner_id, parent_id, template_id, item_order, hierarchy, id_hierarchy, active, default_content, show_in_menu, cachable, menu_text, markup, metadata, titleattribute, accesskey, tabindex, last_modified_by, create_date, modified_date) VALUES (?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?)";
+		$query = "INSERT INTO ".$config["db_prefix"]."content (content_id, content_name, content_alias, type, owner_id, parent_id, template_id, item_order, hierarchy, id_hierarchy, active, default_content, show_in_menu, cachable, secure, menu_text, markup, metadata, titleattribute, accesskey, tabindex, last_modified_by, create_date, modified_date) VALUES (?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?)";
 
 		$dbresult = $db->Execute($query, array(
 			$newid,
@@ -1129,6 +1211,7 @@ class ContentBase
 			($this->mDefaultContent == true ? 1 : 0),
 			($this->mShowInMenu == true     ? 1 : 0),
 			($this->mCachable == true       ? 1 : 0),
+			$this->mSecure,
 			$this->mMenuText,
 			$this->mMarkup,
 			$this->mMetadata,
@@ -1186,7 +1269,56 @@ class ContentBase
      */
 	function ValidateData()
 	{
-		return FALSE;
+	  $errors = array();
+
+	  if ($this->mParentId < -1) 
+	    {
+	      $errors[] = lang('invalidparent');
+	      $result = false;
+	    }
+	  
+	  if ($this->mName == '')
+	    {
+	      if ($this->mMenuText != '')
+		{
+		  $this->mName = $this->mMenuText;
+		}
+	      else
+		{
+		  $errors[]= lang('nofieldgiven',array(lang('title')));
+		  $result = false;
+		}
+	    }
+	  
+	  if ($this->mMenuText == '')
+	    {
+	      if ($this->mName != '')
+		{
+		  $this->mMenuText = $this->mName;
+		}
+	      else
+		{
+		  $errors[]=lang('nofieldgiven',array(lang('menutext')));
+		  $result = false;
+		}
+	    }
+		
+	  if (!$this->HandlesAlias())
+	    {
+	      if ($this->mAlias != $this->mOldAlias || ($this->mAlias == '' && $this->RequiresAlias()) ) 
+		{
+		  global $gCms;
+		  $contentops =& $gCms->GetContentOperations();
+		  $error = $contentops->CheckAliasError($this->mAlias, $this->mId);
+		  if ($error !== FALSE)
+		    {
+		      $errors[]= $error;
+		      $result = false;
+		    }
+		}
+	    }
+
+	  return (count($errors) > 0?$errors:FALSE);
 	}
 
     /**
@@ -1277,92 +1409,213 @@ class ContentBase
      */
     function FillParams($params)
     {
+      // content property parameters
+      $parameters = array('extra1','extra2','extra3','image','thumbnail');
+      foreach ($parameters as $oneparam)
+	{
+	  if (isset($params[$oneparam]))
+	    {
+	      $this->SetPropertyValue($oneparam, $params[$oneparam]);
+	    }
+	}
+
+      // go through the list of base parameters
+      // setting them from params
+      
+      // title
+      if (isset($params['title']))
+	{
+	  $this->mName = $params['title'];
+	}
+
+      // menu text
+      if (isset($params['menutext']))
+	{
+	  $this->mMenuText = $params['menutext'];
+	}
+
+      // parent id
+      if( isset($params['parent_id']) )
+	{
+	  if ($this->mParentId != $params['parent_id'])
+	    {
+	      $this->mHierarchy = '';
+	      $this->mItemOrder = -1;
+	    }
+	  $this->mParentId = $params['parent_id'];
+	}
+
+      // active
+      if (isset($params['active']))
+	{
+	  $this->mActive = $params['active'];
+	  if( $this->DefaultContent() )
+	    {
+	      $this->mActive = 1;
+	    }
+	}
+      
+      // show in menu
+      if (isset($params['showinmenu']))
+	{
+	  $this->mShowInMenu = $params['showinmenu'];
+	}
+
+      // alias
+      $tmp = '';
+      if (isset($params['alias']))
+	{
+	  $tmp = trim($params['alias']);
+	}
+      $this->SetAlias($tmp);
+
+      // target
+      if (isset($params['target']))
+	{
+	  $val = $params['target'];
+	  if( $val == '---' )
+	    {
+	      $val = '';
+	    }
+	  $this->SetPropertyValue('target', $val);
+	} 
+
+      // title attribute
+      if (isset($params['titleattribute']))
+	{
+	  $this->mTitleAttribute = $params['titleattribute'];
+	}
+
+      // accesskey
+      if (isset($params['accesskey']))
+	{
+	  $this->mAccessKey = $params['accesskey'];
+	}
+
+      // tab index
+      if (isset($params['tabindex']))
+	{
+	  $this->mTabIndex = $params['tabindex'];
+	}
+
+      // cachable
+      if (isset($params['cachable']))
+	{
+	  $this->mCachable = $params['cachable'];
+	}
+      else
+	{
+	  $this->_handleRemovedBaseProperty('cachable','mCachable');
+	}
+
+      // secure
+      if (isset($params['secure']))
+	{
+	  $this->mSecure = $params['secure'];
+	}
+      else
+	{
+	  $this->_handleRemovedBaseProperty('secure','mSecure');
+	}
+
+      // owner
+      if (isset($params["ownerid"]))
+	{
+	  $this->SetOwner($params["ownerid"]);
+	}
+	 
+      // additional editors
+      if (isset($params["additional_editors"]))
+	{
+	  $addtarray = array();
+	  if( is_array($params['additional_editors']) )
+	    {
+	      foreach ($params["additional_editors"] as $addt_user_id)
+		{
+		  $addtarray[] = $addt_user_id;
+		}
+	    }
+	  $this->SetAdditionalEditors($addtarray);
+	}
     }
 
     /**
      * Function for content types to override to set their proper generated URL
      */
-    function GetURL($rewrite = true)
-    {
-	global $gCms;
-	$config = &$gCms->GetConfig();
-	$url = "";
-	$alias = ($this->mAlias != ''?$this->mAlias:$this->mId);
-
-	/* use root_url for default content */
-        if($this->mDefaultContent) {
-         $url =  $config['root_url']. '/';
-         return $url;
-        }
-
-	if ($config["assume_mod_rewrite"] && $rewrite == true)
+	function GetURL($rewrite = true)
 	{
-	    if ($config['use_hierarchy'] == true)
-	    {
-		$url = $config['root_url']. '/' . $this->HierarchyPath() . (isset($config['page_extension'])?$config['page_extension']:'.html');
-	    }
-	    else
-	    {
-		$url = $config['root_url']. '/' . $alias . (isset($config['page_extension'])?$config['page_extension']:'.html');
-	    }
-	}
-	else
-	{
-	    if (isset($_SERVER['PHP_SELF']) && $config['internal_pretty_urls'] == true)
-	    {
-		if ($config['use_hierarchy'] == true)
+		global $gCms;
+		$config = &$gCms->GetConfig();
+		$url = "";
+		$alias = ($this->mAlias != ''?$this->mAlias:$this->mId);
+
+		$base_url = $config['root_url'];
+		if( $this->Secure() )
+		  {
+		    if( isset($config['ssl_url']) )
+		      {
+			$base_url = $config['ssl_url'];
+		      }
+		    else
+		      {
+			$base_url = str_replace('http://','https://',$base_url);
+		      }
+		  }
+
+		/* use root_url for default content */
+		if($this->mDefaultContent) {
+			$url =  $base_url . '/';
+			return $url;
+		}
+
+		if ($config["url_rewriting"] == 'mod_rewrite' && $rewrite == true)
 		{
-		    $url = $config['root_url'] . '/index.php/' . $this->HierarchyPath() . (isset($config['page_extension'])?$config['page_extension']:'.html');
+			if ($config['use_hierarchy'] == true)
+			{
+				$url = $base_url. '/' . $this->HierarchyPath() . (isset($config['page_extension'])?$config['page_extension']:'.html');
+			}
+			else
+			{
+				$url = $base_url . '/' . $alias . (isset($config['page_extension'])?$config['page_extension']:'.html');
+			}
 		}
 		else
 		{
-		    $url = $config['root_url'] . '/index.php/' . $alias . (isset($config['page_extension'])?$config['page_extension']:'.html');
+			if (isset($_SERVER['PHP_SELF']) && $config['url_rewriting'] == 'internal')
+			{
+				if ($config['use_hierarchy'] == true)
+				{
+					$url = $base_url . '/index.php/' . $this->HierarchyPath() . (isset($config['page_extension'])?$config['page_extension']:'.html');
+				}
+				else
+				{
+					$url = $base_url . '/index.php/' . $alias . (isset($config['page_extension'])?$config['page_extension']:'.html');
+				}
+			}
+			else
+			{
+				$url = $base_url . '/index.php?' . $config['query_var'] . '=' . $alias;
+			}
 		}
-	    }
-	    else
-	    {
-		$url = $config['root_url'] . '/index.php?' . $config['query_var'] . '=' . $alias;
-	    }
-	}
 		return $url;
-    }
-
-    /*
-    function MakeHierarchyURL($ext='')
-    {
-	global $gCms;
-	$hm =& $gCms->GetHierarchyManager();
-
-	$path = '/' . $this->Alias();
-
-	$node =& $hm->getNodeById($this->ParentId());
-	if(isset($node))
-	{
-	    $content =& $node->GetContent();
-	    if (isset($content))
-	    {
-		$path = '/' . $content->HierarchyPath();
-	    }
 	}
 
-	$result = $path;
-
-	if ($ext != '')
-	    $result = $path . $ext;
-
-	return $result;
-    }
-    */
 
     /**
      * Show the content
      */
     function Show($param = '')
     {
-	# :TODO:
-	return "<tr><td>Show Not Defined</td></tr>";
     }
 	
+    /**
+     * Handle Auto Aliasing 
+     */
+    function DoAutoAlias()
+    {
+      return $this->_add_mode;
+    }
+
     /**
     * allow the content module to handle custom tags. Typically used for parameters in {content} tags
     */
@@ -1371,14 +1624,6 @@ class ContentBase
 	return $tpl_source;
     }
 
-    /**
-     * Returns a list of tab names that should be used when adding or editing this type of content
-     */
-    function GetTabDefinitions()
-    {
-	return array();
-    }
-	
     /**
      * Returns the tab names used in the add and edit content page.  If it's an empty array, then
      * the tabs won't show at all.
@@ -1388,9 +1633,6 @@ class ContentBase
         return array();
     }
 
-    /**
-     * Show the Alternate Edit interface
-     */
     function EditAsArray($adding = false, $tab = 0, $showadmin = false)
     {
 	# :TODO:
@@ -1412,14 +1654,6 @@ class ContentBase
 	return $text;
     }
 
-    /**
-     * Show the Advanced Edit interface
-     */
-    function AdvancedEdit($adding = false)
-    {
-	# :TODO:
-	return "<tr><td>Advanced Edit Not Defined</td></tr>";
-    }
 
     /**
      * Show Help
@@ -1496,7 +1730,8 @@ class ContentBase
 		$ret = array();
 
 		$ret[] = lang('additionaleditors');
-		$text = '<select name="additional_editors[]" multiple="multiple" size="5">';
+		$text = '<input name="additional_editors" type="hidden" value=""/>';
+		$text .= '<select name="additional_editors[]" multiple="multiple" size="5">';
 
 		global $gCms;
 		$userops =& $gCms->GetUserOperations();
@@ -1542,6 +1777,337 @@ class ContentBase
 	{
 		return FALSE;
 	}
+
+	function SetAddMode($flag = true)
+	{
+	  $this->_add_mode = $flag;
+	}
+
+	/* private */
+	function _handleRemovedBaseProperty($name,$member)
+	{
+		if( !is_array($this->_attributes) ) return FALSE;
+		if( !in_array($name,$this->_attributes) )
+		{
+			if( isset($this->_prop_defaults[$name]) )
+			{
+				$this->$member = $this->_prop_defaults[$name];
+				return TRUE;
+			}
+		}
+		return FALSE;
+	}
+
+	/* private */
+	function RemoveProperty($name,$dflt)
+	{
+	  if( !is_array($this->_attributes) ) return;
+	  $tmp = array();
+	  for( $i = 0; $i < count($this->_attributes); $i++ )
+	    {
+	      if( is_array($this->_attributes[$i]) && $this->_attributes[$i][0] == $name )
+		{
+		  continue;
+		}
+	      $tmp[] = $this->_attributes[$i];
+	    }
+	  $this->_attributes = $tmp;
+	  $this->_prop_defaults[$name] = $dflt;
+	}
+
+	/* private */
+	/*
+	 * Add a property that is directly associtated with a field in the content table.
+	 */
+	function AddBaseProperty($name,$priority,$is_required = 0,$type = 'string')
+	{
+	  if( !is_array($this->_attributes) )
+	    {
+	      $this->_attributes = array();
+	    }
+
+	  $this->_attributes[] = array($name,$priority,$is_required);
+	}
+
+	/* private */
+	/*
+	 * Add a property to the content_props table for this content item
+	 * This property will not be effected by the basic_attributes list.
+	 */
+	function AddExtraProperty($name,$type='string')
+	{
+	  $this->mProperties->add($type,$name);
+	}
+
+	/* private */
+	/*
+	 * Add a property to the content_props table for this content item
+	 */
+	function AddContentProperty($name,$priority,$is_required = 0,$type = 'string')
+	{
+	  if( !is_array($this->_attributes) )
+	    {
+	      $this->_attributes = array();
+	    }
+	  $this->mProperties->add($type,$name);
+	  $this->_attributes[] = array($name,$priority,$is_required);
+	}
+
+	/* private */
+	/*
+	 * Given the list of registered properties, cross reference with our
+	 * basic attributes list, and figure out which ones should be displayed
+	 */
+	function display_attributes($adding,$negative = 0)
+	{
+	  // get our required attributes
+	  $basic_attributes = array();
+	  foreach( $this->_attributes as $one )
+	    {
+	      if( $one[2] == 1 ) $basic_attributes[] = $one;
+	    }
+
+	  // merge in preferred basic attributes
+	  $tmp = get_site_preference('basic_attributes');
+	  if( !empty($tmp) )
+	    {
+	      $tmp = explode(',',$tmp);
+	      foreach( $tmp as $basic )
+		{
+		  $found = NULL;
+		  foreach( $this->_attributes as $one )
+		    {
+		      if( $one[0] == $basic ) {
+			$found = $one;
+			break;
+		      }
+		    }
+		  if( $found )
+		    {
+		      $basic_attributes[] = $found;
+		    }
+		}
+	    }
+
+	  $attrs = $basic_attributes;
+	  if( $negative )
+	    {
+	      // build a new list of all properties... except those in the basic_attributes
+	      $attrs = array();
+	      foreach( $this->_attributes as $one )
+		{
+		  $found = 0;
+		  foreach( $basic_attributes as $basic )
+		    {
+		      if( $basic[0] == $one[0] )
+			{
+			  $found = 1;
+			}
+		    }
+
+		  if( !$found )
+		    {
+		      $attrs[] = $one;
+		    }
+		}
+	    }
+
+	  // remove any duplicates
+	  $tmp = array();
+	  foreach( $attrs as $one )
+	    {
+	      $found = 0;
+	      foreach( $tmp as $t1 )
+		{
+		  if( $one[0] == $t1[0] )
+		    {
+		      $found = 1;
+		      break;
+		    }
+		}
+	      if( !$found )
+		{
+		  $tmp[] = $one;
+		}
+	    }
+	  $attrs = $tmp;
+
+	  // sort the attributes on the 2nd element...
+	  $fn = create_function('$a,$b','if( $a[1] < $b[1] ) return -1; else if( $a[1] == $b[1] ) return 0; else return $b;');
+	  usort($attrs,$fn);
+
+	  $tmp = $this->display_admin_attributes($attrs,$adding);
+	  return $tmp;
+	}
+
+	/* private */
+	function display_admin_attributes($attributelist,$adding)
+	{
+	  // sort the attributes
+
+	  $ret = array();
+	  foreach( $attributelist as $one )
+	    {
+	      $ret[] = $this->display_single_element($one[0],$adding);
+	    }
+	  return $ret;
+	}
+
+	/* protected */
+	function display_single_element($one,$adding)
+	{
+	  global $gCms;
+	  $config =& $gCms->GetConfig();
+
+	  switch( $one )
+	    {
+	    case 'cachable':
+	      return array(lang('cachable').':','<input type="hidden" name="cachable" value="0"/><input class="pagecheckbox" type="checkbox" value="1" name="cachable"'.($this->mCachable?' checked="checked"':'').' />');
+	      break;
+	
+	    case 'title':
+	      {
+		return array(lang('title').':','<input type="text" name="title" value="'.cms_htmlentities($this->mName).'" />');
+	      }
+	      break;
+	      
+	    case 'menutext':
+	      {
+		return array(lang('menutext').':','<input type="text" name="menutext" value="'.cms_htmlentities($this->mMenuText).'" />');
+	      }
+	      break;
+	      
+	    case 'parent':
+		{
+		  $contentops =& $gCms->GetContentOperations();
+		  $tmp = $contentops->CreateHierarchyDropdown($this->mId, $this->mParentId, 'parent_id', 0, 1, 0, 1);
+		  if( empty($tmp) && !check_permission(get_userid(),'Manage All Content') )
+		    return array('','<input type="hidden" name="parent_id" value="'.$this->mParentId.'" />');
+		  if( !empty($tmp) ) return array(lang('parent').':',$tmp);
+		}
+	      break;
+
+	    case 'active':
+	      if( !$this->DefaultContent() )
+		{
+		  return array(lang('active').':','<input type="hidden" name="active" value="0"/><input class="pagecheckbox" type="checkbox" name="active" value="1"'.($this->mActive?' checked="checked"':'').' />');
+		}
+	      break;
+	      
+	    case 'showinmenu':
+	      return array(lang('showinmenu').':','<input type="hidden" name="showinmenu" value="0"/><input class="pagecheckbox" type="checkbox" value="1" name="showinmenu"'.($this->mShowInMenu?' checked="checked"':'').' />');
+	      break;
+	      
+	    case 'target':
+	      {
+		$text = '<option value="---">'.lang('none').'</option>';
+		$text .= '<option value="_blank"'.($this->GetPropertyValue('target')=='_blank'?' selected="selected"':'').'>_blank</option>';
+		$text .= '<option value="_parent"'.($this->GetPropertyValue('target')=='_parent'?' selected="selected"':'').'>_parent</option>';
+		$text .= '<option value="_self"'.($this->GetPropertyValue('target')=='_self'?' selected="selected"':'').'>_self</option>';
+		$text .= '<option value="_top"'.($this->GetPropertyValue('target')=='_top'?' selected="selected"':'').'>_top</option>';
+		return array(lang('target').':','<select name="target">'.$text.'</select>');
+		
+	      }
+	      break;
+	      
+	    case 'alias':
+	      return array(lang('pagealias').':','<input type="text" name="alias" value="'.$this->mAlias.'" />');
+	      break;
+	      
+	    case 'secure':
+	      {
+		$opt = '';
+		if( $this->mSecure )
+		  {
+		    $opt = ' checked="checked"';
+		  }
+		$str  = '<input type="hidden" name="secure" value="0"/>';
+                $str .= '<input type="checkbox" name="secure" value="1"'.$opt.'/>';
+		return array(lang('secure_page').':',$str);
+	      }
+	      break;
+
+	    case 'image':
+	      {
+		$dir = $config['image_uploads_path'];
+		$data = $this->GetPropertyValue('image');
+		$dropdown = create_file_dropdown('image',$dir,$data,'jpg,jpeg,png,gif','',true,'','thumb_');
+		return array(lang('image').':',$dropdown);
+	      }
+	      break;
+	      
+	    case 'thumbnail':
+	      {
+		$dir = $config['image_uploads_path'];
+		$data = $this->GetPropertyValue('thumbnail');
+		$dropdown = create_file_dropdown('thumbnail',$dir,$data,'jpg,jpeg,png,gif','',true,'','thumb_',0);
+		return array(lang('thumbnail').':',$dropdown);
+	      }
+	      break;
+	      
+	    case 'titleattribute':
+	      {
+		return array(lang('titleattribute').':','<input type="text" name="titleattribute" maxlength="255" size="80" value="'.cms_htmlentities($this->mTitleAttribute).'" />');
+	      }
+	      break;
+	      
+	    case 'accesskey':
+	      {
+		return array(lang('accesskey').':','<input type="text" name="accesskey" maxlength="5" value="'.cms_htmlentities($this->mAccessKey).'" />');
+	      }
+	      break;
+
+	    case 'tabindex':
+	      {
+		return array(lang('tabindex').':','<input type="text" name="tabindex" maxlength="5" value="'.cms_htmlentities($this->mTabIndex).'" />');
+	      }
+	      break;
+	      
+	    case 'extra1':
+	      {
+		return array(lang('extra1').':','<input type="text" name="extra1" maxlength="255" size="80" value="'.cms_htmlentities($this->GetPropertyValue('extra1')).'" />');
+	      }
+	      break;
+	      
+	    case 'extra2':
+	      {
+		return array(lang('extra2').':','<input type="text" name="extra2" maxlength="255" size="80" value="'.cms_htmlentities($this->GetPropertyValue('extra2')).'" />');
+	      }
+	      break;
+	      
+	    case 'extra3':
+	      {
+		return array(lang('extra3').':','<input type="text" name="extra3" maxlength="255" size="80" value="'.cms_htmlentities($this->GetPropertyValue('extra3')).'" />');
+	      }
+	      break;
+
+	    case 'owner':
+	      {
+		$showadmin = check_ownership(get_userid(), $this->Id());
+		$userops =& $gCms->GetUserOperations();
+		if (!$adding && $showadmin)
+		  {
+		    return array(lang('owner').':', $userops->GenerateDropdown($this->Owner()));
+		  }
+	      }
+	      break;
+
+	    case 'additionaleditors':
+	      {
+		// do owner/additional-editor stuff
+		if( $adding || check_ownership(get_userid(),$this->Id()) )
+		  {
+		    return $this->ShowAdditionalEditors();
+		  }
+	      }
+	      break;
+
+	    default:
+	      stack_trace();
+	      die('unknown property '.$one);
+	    }
+	}
+
 }
 
 /**
@@ -1585,7 +2151,7 @@ class ContentProperties
 	{
 		#debug_buffer($this->mPropertyNames);
 		if (!isset($this->mPropertyNames))
-		$this->mPropertyNames = array();
+		  $this->mPropertyNames = array();
 		return in_array($name, $this->mPropertyNames);
 	}
 
@@ -1630,7 +2196,6 @@ class ContentProperties
 
 	function Load($content_id)
 	{
-		debug_buffer('load properties called');
 		if (count($this->mPropertyNames) > 0)
 		{
 			global $gCms, $sql_queries, $debug_errors;
