@@ -70,7 +70,7 @@ class ContentOperations
 		
 		if (ContentOperations::LoadContentType($type))
 		{
-			$result =& new $type;
+			$result = new $type;
 		}
 		
 		return $result;
@@ -556,9 +556,9 @@ class ContentOperations
 				}
 			}
 
-			$tree = &new Tree();
+			$tree = new Tree();
 			debug_buffer('', 'Start Loading Children into Tree');
-			$tree = &Tree::createFromList($nodes, '.');
+			$tree = Tree::createFromList($nodes, '.');
 			debug_buffer('', 'End Loading Children into Tree');
 		}
 
@@ -736,7 +736,7 @@ class ContentOperations
 		return $contentcache;
 	}
 
-	function CreateHierarchyDropdown($current = '', $parent = '', $name = 'parent_id', $allowcurrent = 0, $use_perms = 0, $ignore_current = 0)
+	function CreateHierarchyDropdown($current = '', $parent = '', $name = 'parent_id', $allowcurrent = 0, $use_perms = 0, $ignore_current = 0, $allow_all = false)
 	{
 		$result = '';
 		$userid = -1;
@@ -774,6 +774,13 @@ class ContentOperations
 			      $value = -1;
 			    }
 
+			  // If it doesn't have a valid link...
+			  // don't include it.
+			  if( !$allow_all && !$one->HasUsableLink() )
+			    {
+			      continue;
+			    }
+
 			  // If it's a child of the current, we don't want to show it as it
 			  // could cause a deadlock.
 			  if (!$allowcurrent && 
@@ -969,7 +976,8 @@ class ContentOperations
 	{
 		#Change padded numbers back into user-friendly values
 		$tmp = '';
-		$levels = split('\.', $position);
+    $levels = preg_split('/\./', $position);
+    
 		foreach ($levels as $onelevel)
 		{
 			$tmp .= ltrim($onelevel, '0') . '.';
@@ -982,7 +990,9 @@ class ContentOperations
 	{
 		#Change user-friendly values into padded numbers
 		$tmp = '';
-		$levels = split('\.', $position);
+        
+    $levels = preg_split('/\./', $position);
+    
 		foreach ($levels as $onelevel)
 		{
 			$tmp .= str_pad($onelevel, 5, '0', STR_PAD_LEFT) . '.';
