@@ -16,7 +16,7 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA	02111-1307	USA
 #
-#$Id: class.module.inc.php 5921 2009-08-20 16:05:12Z calguy1000 $
+#$Id: class.module.inc.php 6271 2010-05-01 17:38:44Z calguy1000 $
 
 /**
  * Base module class.
@@ -58,8 +58,10 @@ class CMSModule
 		$this->cms =& $gCms;
 		$this->config =& $gCms->GetConfig();
 
+		global $CMS_STYLESHEET;
 		global $CMS_ADMIN_PAGE;
 		global $CMS_MODULE_PAGE;
+		global $CMS_INSTALL_PAGE;
 		if (isset($CMS_ADMIN_PAGE))
 		{
 			$this->curlang = '';
@@ -67,7 +69,7 @@ class CMSModule
 		else
 		{
 		  $this->curlang = get_site_preference('frontendlang','');
-		  if (isset($config['locale']) && $config['locale'] != '') {
+		  if (isset($this->config['locale']) && $this->config['locale'] != '') {
 		      $this->curlang = $config['locale'];
 		    }
 		  if( $this->curlang == '' ) {
@@ -90,7 +92,7 @@ class CMSModule
 		#$smarty = new CMSModuleSmarty($config, $this->GetName());
 		$this->smarty = &$gCms->GetSmarty();
 
-		if( !isset($CMS_ADMIN_PAGE) || isset($CMS_MODULE_PAGE) )
+		if( (!isset($CMS_ADMIN_PAGE)  || isset($CMS_MODULE_PAGE)) && !isset($CMS_STYLESHEET) && !isset($CMS_INSTALL_PAGE))
 		  {
 		    $this->SetParameterType('assign',CLEAN_STRING);
 		    $this->SetParameterType('module',CLEAN_STRING);
@@ -275,7 +277,8 @@ class CMSModule
 	 * @param string Optional language that the admin is using.	 If that language
 	 * is not defined, use en_US.
 	 */
-	function GetHelp($lang = 'en_US')
+	//	function GetHelp($lang = 'en_US')
+	function GetHelp()
 	{
 		return '';
 	}
@@ -308,12 +311,12 @@ class CMSModule
 	function RegisterRoute($routeregex, $defaults = array())
 	{
 		global $gCms;
-		$route =& new CmsRoute();
+		$route = new CmsRoute();
 		$route->module = $this->GetName();
 		$route->defaults = $defaults;
 		$route->regex = $routeregex;
 		$routes =& $gCms->variables['routes'];
-		$routes[] =& $route;
+		$routes[] = $route;
 	}
 
 	/**
@@ -387,7 +390,8 @@ class CMSModule
 	 * @param string Optional language that the admin is using.	 If that language
 	 * is not defined, use en_US.
 	 */
-	function GetAdminDescription($lang = 'en_US')
+	//	function GetAdminDescription($lang = 'en_US')
+	function GetAdminDescription()
 	{
 		return '';
 	}
@@ -527,12 +531,12 @@ class CMSModule
 		$contenttypes =& $gCms->contenttypes;
 		if (!isset($contenttypes[strtolower($name)]))
 		{
-			$obj =& new CmsContentTypePlaceholder();
+			$obj = new CmsContentTypePlaceholder();
 			$obj->type = strtolower($name);
 			$obj->filename = $file;
 			$obj->loaded = false;
 			$obj->friendlyname = ($friendlyname != '' ? $friendlyname : $name);
-			$contenttypes[strtolower($name)] =& $obj;
+			$contenttypes[strtolower($name)] = $obj;
 		}
 	}
 
@@ -572,7 +576,9 @@ class CMSModule
 				$config =& $gCms->GetConfig();
 				$smarty =& $gCms->GetSmarty();
 
-				include($filename);
+				$res = include($filename);
+				if( $res == 1 || $res == '' ) return FALSE;
+				return $res;
 			}
 		}
 		else
@@ -605,7 +611,14 @@ class CMSModule
 		  $config =& $gCms->GetConfig();
 		  $smarty =& $gCms->GetSmarty();
 		  
-		  include($filename);
+		  $res = include($filename);
+		  if( $res == '1' || $res == '') return FALSE;
+		  if( is_string($res)) 
+		    {
+		      $modops = $gCms->GetModuleOperations();
+		      $modops->SetError($res);
+		    }
+		  return $res;
 		}
 		else
 		{
@@ -652,7 +665,11 @@ class CMSModule
 				$config =& $gCms->GetConfig();
 				$smarty =& $gCms->GetSmarty();
 
-				include($filename);
+				$res = include($filename);
+				if( $res == '1' || $res == '' ) return TRUE;
+				$modops = $gCms->GetModuleOperations();
+				$modops->SetError($res);
+				return $res;
 			}
 		}
 	}
@@ -1537,6 +1554,10 @@ class CMSModule
 	{
 		if ($name != '')
 		{
+			//Just in case DoAction is called directly and it's not overridden.
+			//See: http://0x6a616d6573.blogspot.com/2010/02/cms-made-simple-166-file-inclusion.html
+			$name = preg_replace('/[^A-Za-z0-9\-_+]/', '', $name);
+			
 			$filename = dirname(dirname(dirname(__FILE__))) . '/modules/'.$this->GetName().'/action.' . $name . '.php';
 			if (@is_file($filename))
 			{
@@ -1555,6 +1576,7 @@ class CMSModule
 
 	function DoActionBase($name, $id, $params, $returnid='')
 	{
+          $name = preg_replace('/[^A-Za-z0-9\-_+]/', '', $name);
 	  if( $returnid != '' )
 	    {
 	      if( !$this->restrict_unknown_params && 
