@@ -16,7 +16,7 @@
 #along with this program; if not, write to the Free Software
 #Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
-#$Id: misc.functions.php 5451 2009-02-17 15:15:32Z Silmarillion $
+#$Id: misc.functions.php 6101 2010-01-28 19:06:35Z calguy1000 $
 
 /**
  * Misc functions
@@ -31,7 +31,7 @@
  */
 function redirect($to, $noappend=false)
 {
-	$_SERVER['PHP_SELF'] = null;
+     $_SERVER['PHP_SELF'] = null;
 
     global $gCms;
 	if (isset($gCms))
@@ -90,6 +90,9 @@ function redirect($to, $noappend=false)
     }
 	*/
 
+    session_write_close();
+
+
     if (headers_sent() && !(isset($config) && $config['debug'] == true))
     {
         // use javascript instead
@@ -113,11 +116,11 @@ function redirect($to, $noappend=false)
 			echo '<div id="DebugFooter">';
 			global $sql_queries;
 			if (FALSE == empty($sql_queries))
-			  { 
+			  {
 				echo "<div>".$sql_queries."</div>\n";
 			  }
 			foreach ($gCms->errors as $error)
-			{   
+			{
 				echo $error;
 			}
 			echo '</div> <!-- end DebugFooter -->';
@@ -285,7 +288,7 @@ function cms_cleanfile($filename)
 function cms_calculate_url()
 {
 	$result = '';
-	
+
     global $gCms;
     $config =& $gCms->GetConfig();
 
@@ -320,7 +323,7 @@ function cms_calculate_url()
 			$result = $matches[1];
 		}
 	}
-	
+
 	//trim off the extension, if there is one set
 	if ($config['page_extension'] != '' && endswith($result, $config['page_extension']))
 	{
@@ -328,7 +331,7 @@ function cms_calculate_url()
 	}
 
 	return $result;
-	
+
 }
 
 /**
@@ -337,11 +340,11 @@ function cms_calculate_url()
  * @param unknown $val
  * @param integer $quote_style
  * @return unknown
- * 
+ *
  * $quote_style may be one of:
- *     ENT_COMPAT   : Will convert double-quotes and leave single-quotes alone. 
- *     ENT_QUOTES   : Will convert both double and single quotes. 
- *     ENT_NOQUOTES : Will leave both double and single quotes unconverted. 
+ *     ENT_COMPAT   : Will convert double-quotes and leave single-quotes alone.
+ *     ENT_QUOTES   : Will convert both double and single quotes.
+ *     ENT_NOQUOTES : Will leave both double and single quotes unconverted.
  */
 function my_htmlentities($val, $convert_single_quotes = false)
 {
@@ -349,49 +352,49 @@ function my_htmlentities($val, $convert_single_quotes = false)
 	{
 		return "";
 	}
-	$val = str_replace( "&#032;", " ", $val ); 
+	$val = str_replace( "&#032;", " ", $val );
 
-	//Remove sneaky spaces 
-	// $val = str_replace( chr(0xCA), "", $val );   
+	//Remove sneaky spaces
+	// $val = str_replace( chr(0xCA), "", $val );
 
-	$val = str_replace( "&"            , "&amp;"         , $val ); 
-	$val = str_replace( "<!--"         , "&#60;&#33;--"  , $val ); 
-	$val = str_replace( "-->"          , "--&#62;"       , $val ); 
-	$val = preg_replace( "/<script/i"  , "&#60;script"   , $val ); 
-	$val = str_replace( ">"            , "&gt;"          , $val ); 
-	$val = str_replace( "<"            , "&lt;"          , $val ); 
-	
-	
-	$val = str_replace( "\""           , "&quot;"        , $val ); 
+	$val = str_replace( "&"            , "&amp;"         , $val );
+	$val = str_replace( "<!--"         , "&#60;&#33;--"  , $val );
+	$val = str_replace( "-->"          , "--&#62;"       , $val );
+	$val = preg_replace( "/<script/i"  , "&#60;script"   , $val );
+	$val = str_replace( ">"            , "&gt;"          , $val );
+	$val = str_replace( "<"            , "&lt;"          , $val );
 
-	// Uncomment it if you need to convert literal newlines 
-	//$val = preg_replace( "/\n/"        , "<br>"          , $val ); 
 
-	$val = preg_replace( "/\\$/"      , "&#036;"        , $val ); 
+	$val = str_replace( "\""           , "&quot;"        , $val );
 
-	// Uncomment it if you need to remove literal carriage returns 
-	//$val = preg_replace( "/\r/"        , ""              , $val ); 
+	// Uncomment it if you need to convert literal newlines
+	//$val = preg_replace( "/\n/"        , "<br>"          , $val );
 
-	$val = str_replace( "!"            , "&#33;"         , $val ); 
-	$val = str_replace( "'"            , "&#39;"         , $val ); 
-	 
-	// Uncomment if you need to convert unicode chars 
-	//$val = preg_replace("/&#([0-9]+);/s", "&#\1;", $val ); 
+	$val = preg_replace( "/\\$/"      , "&#036;"        , $val );
 
-	// Strip slashes if not already done so. 
+	// Uncomment it if you need to remove literal carriage returns
+	//$val = preg_replace( "/\r/"        , ""              , $val );
+
+	$val = str_replace( "!"            , "&#33;"         , $val );
+	$val = str_replace( "'"            , "&#39;"         , $val );
+
+	// Uncomment if you need to convert unicode chars
+	//$val = preg_replace("/&#([0-9]+);/s", "&#\1;", $val );
+
+	// Strip slashes if not already done so.
+
+	//if ( get_magic_quotes_gpc() )
+	//{
+	//	$val = stripslashes($val);
+	//}
 
-	//if ( get_magic_quotes_gpc() ) 
-	//{ 
-	//	$val = stripslashes($val); 
-	//} 
-	
 	if ($convert_single_quotes)
 	{
 		$val = str_replace("\\'", "&apos;", $val);
 		$val = str_replace("'", "&apos;", $val);
 	}
 
-	// Swop user inputted backslashes 
+	// Swop user inputted backslashes
 
 	//$val = preg_replace( "/\(?!&#|?#)/", "&#092;", $val );
 
@@ -411,43 +414,43 @@ function cms_utf8entities($val)
 	{
 		return "";
 	}
-	$val = str_replace( "&#032;", " ", $val ); 
+	$val = str_replace( "&#032;", " ", $val );
 
-	//Remove sneaky spaces 
-	// $val = str_replace( chr(0xCA), "", $val );   
+	//Remove sneaky spaces
+	// $val = str_replace( chr(0xCA), "", $val );
 
-	$val = str_replace( "&"            , "\u0026"         , $val ); 
-#	$val = str_replace( "<!--"         , "&#60;&#33;--"  , $val ); 
-#	$val = str_replace( "-->"          , "--&#62;"       , $val ); 
-#	$val = preg_replace( "/<script/i"  , "&#60;script"   , $val ); 
-	$val = str_replace( ">"            , "\u003E"          , $val ); 
-	$val = str_replace( "<"            , "\u003C"          , $val ); 
-	
-	
-	$val = str_replace( "\""           , "\u0022"        , $val ); 
+	$val = str_replace( "&"            , "\u0026"         , $val );
+#	$val = str_replace( "<!--"         , "&#60;&#33;--"  , $val );
+#	$val = str_replace( "-->"          , "--&#62;"       , $val );
+#	$val = preg_replace( "/<script/i"  , "&#60;script"   , $val );
+	$val = str_replace( ">"            , "\u003E"          , $val );
+	$val = str_replace( "<"            , "\u003C"          , $val );
 
-	// Uncomment it if you need to convert literal newlines 
-	//$val = preg_replace( "/\n/"        , "<br>"          , $val ); 
 
-	#$val = preg_replace( "/\\$/"      , "&#036;"        , $val ); 
+	$val = str_replace( "\""           , "\u0022"        , $val );
 
-	// Uncomment it if you need to remove literal carriage returns 
-	//$val = preg_replace( "/\r/"        , ""              , $val ); 
+	// Uncomment it if you need to convert literal newlines
+	//$val = preg_replace( "/\n/"        , "<br>"          , $val );
 
-	$val = str_replace( "!"            , "\u0021"         , $val ); 
-	$val = str_replace( "'"            , "\u0027"         , $val ); 
-	 
-	// Uncomment if you need to convert unicode chars 
-	//$val = preg_replace("/&#([0-9]+);/s", "&#\1;", $val ); 
+	#$val = preg_replace( "/\\$/"      , "&#036;"        , $val );
 
-	// Strip slashes if not already done so. 
+	// Uncomment it if you need to remove literal carriage returns
+	//$val = preg_replace( "/\r/"        , ""              , $val );
 
-	//if ( get_magic_quotes_gpc() ) 
-	//{ 
-	//	$val = stripslashes($val); 
-	//} 
+	$val = str_replace( "!"            , "\u0021"         , $val );
+	$val = str_replace( "'"            , "\u0027"         , $val );
 
-	// Swop user inputted backslashes 
+	// Uncomment if you need to convert unicode chars
+	//$val = preg_replace("/&#([0-9]+);/s", "&#\1;", $val );
+
+	// Strip slashes if not already done so.
+
+	//if ( get_magic_quotes_gpc() )
+	//{
+	//	$val = stripslashes($val);
+	//}
+
+	// Swop user inputted backslashes
 
 	//$val = preg_replace( "/\(?!&#|?#)/", "&#092;", $val );
 
@@ -473,33 +476,60 @@ function nl2pnbr( $text )
 	return $text;
 }
 
-function debug_bt() 
-{ 
-    $bt=debug_backtrace(); 
-    $file = $bt[0]['file']; 
-    $line = $bt[0]['line']; 
- 
-    echo "\n\n<p><b>Backtrace in $file on line $line</b></p>\n"; 
- 
-    $bt = array_reverse($bt); 
-    echo "<pre><dl>\n"; 
-    foreach($bt as $trace) 
-    { 
-        $file = $trace['file']; 
-        $line = $trace['line']; 
-        $function = $trace['function']; 
-        $args = implode(',', $trace['args']); 
+function debug_bt_to_log()
+{
+    $bt=debug_backtrace();
+    $file = $bt[0]['file'];
+    $line = $bt[0]['line'];
+
+    $out = array();
+    $out[] = "Backtrace in $file on line $line";
+
+    $bt = array_reverse($bt);
+    foreach($bt as $trace)
+    {
+      if( $elem['function'] == 'debug_bt_to_log' ) continue;
+
+      $file = $trace['file'];
+      $line = $trace['line'];
+      $function = $trace['function'];
+      $out[] = "$function at $file:$line"; 
+    }
+
+    $filename = TMP_CACHE_LOCATION . '/debug.log';
+    foreach ($out as $txt)
+      {
+	error_log($txt . "\n", 3, $filename);
+      }
+}
+
+function debug_bt()
+{
+    $bt=debug_backtrace();
+    $file = $bt[0]['file'];
+    $line = $bt[0]['line'];
+
+    echo "\n\n<p><b>Backtrace in $file on line $line</b></p>\n";
+
+    $bt = array_reverse($bt);
+    echo "<pre><dl>\n";
+    foreach($bt as $trace)
+    {
+        $file = $trace['file'];
+        $line = $trace['line'];
+        $function = $trace['function'];
+        $args = implode(',', $trace['args']);
         echo "
-        <dt><b>$function</b>($args) </dt> 
-        <dd>$file on line $line</dd> 
+        <dt><b>$function</b>($args) </dt>
+        <dd>$file on line $line</dd>
 		";
-	} 
-    echo "</dl></pre>\n"; 
+	}
+    echo "</dl></pre>\n";
 }
 
 /**
 * Debug function to display $var nicely in html.
-* 
+*
 * @param mixed $var
 * @param string $title (optional)
 * @param boolean $echo_to_screen (optional)
@@ -515,14 +545,14 @@ function debug_display($var, $title="", $echo_to_screen = true, $use_html = true
 		$starttime = $variables['starttime'];
 	else
 		$variables['starttime'] = $starttime;
-	
+
 	$titleText = "Debug: ";
 	if($title)
 	{
 		$titleText = "Debug display of '$title':";
 	}
 	$titleText .= '(' . microtime_diff($starttime,microtime()) . ')';
-	
+
 	if (function_exists('memory_get_usage'))
 	{
 		$titleText .= ' - ('.memory_get_usage().')';
@@ -549,7 +579,14 @@ function debug_display($var, $title="", $echo_to_screen = true, $use_html = true
 		}
 		elseif(is_string($var))
 		{
+		  if( $use_html )
+		    {
 			print_r(htmlentities(str_replace("\t", '  ', $var)));
+		    }
+		  else
+		    {
+ 		      print_r($var);
+		    }
 		}
 		elseif(is_bool($var))
 		{
@@ -619,7 +656,7 @@ function debug_buffer($var, $title="")
 	if ($gCms)
 	{
 		$config =& $gCms->GetConfig();
-	
+
 		//debug_to_log($var, $title='');
 
 		if($config["debug"] == true)
@@ -635,7 +672,7 @@ function debug_sql($str, $newline)
 	if ($gCms)
 	{
 		$config =& $gCms->GetConfig();
-	
+
 		if($config["debug"] == true)
 		{
 			$gCms->errors[] = debug_display($str, '', false, true);
@@ -649,7 +686,7 @@ function debug_sql($str, $newline)
 *		$default_value.
 *		If $session_key is set, then will return session value in preference
 *		to $default_value if $_REQUEST[$value] is not set.
-* 
+*
 * @param string $value
 * @param mixed $default_value (optional)
 * @param string $session_key (optional)
@@ -685,7 +722,7 @@ function get_request_value($value, $default_value = '', $session_key = '')
 * Return $value if it's set and same basic type as $default_value,
 *			otherwise return $default_value. Note. Also will trim($value)
 *			if $value is not numeric.
-* 
+*
 * @param string $value
 * @param mixed $default_value
 * @return mixed
@@ -729,19 +766,19 @@ function get_value_with_default($value, $default_value = '', $session_key = '')
 			}
 		}
 	}
-	
+
 	if($session_key != '')
 	{
 		$_SESSION['default_values'][$session_key] = $return_value;
 	}
-	
+
 	return $return_value;
 }
 
 /**
  * Retrieve the $value from the $parameters array checking for
  * $parameters[$value] and $params[$id.$value]. Returns $default
- * if $value is not in $params array. 
+ * if $value is not in $params array.
  * Note: This function will also trim() string values.
  *
  * @param array $parameters
@@ -780,7 +817,7 @@ function get_parameter_value($parameters, $value, $default_value = '', $session_
 			{
 				$is_number = true;
 			}
-		
+
 			if(is_array($parameters[$value]))
 			{
 				// $parameters[$value] is an array - validate each element.
@@ -816,7 +853,7 @@ function get_parameter_value($parameters, $value, $default_value = '', $session_
 	{
 		$_SESSION['parameter_values'][$session_key] = $return_value;
 	}
-	
+
 	return $return_value;
 }
 
@@ -841,12 +878,33 @@ function create_encoding_dropdown($name = 'encoding', $selected = '')
 	return $result;
 }
 
+
+function cms_mapi_remove_permission($permission_name)
+{
+  global $gCms;
+  $db =& $gCms->GetDB();
+
+  $query = "SELECT permission_id FROM ".cms_db_prefix()."permissions WHERE permission_name = ?";
+  $row = &$db->GetRow($query, array($permission_name));
+
+  if ($row)
+    {
+      $id = $row["permission_id"];
+
+      $query = "DELETE FROM ".cms_db_prefix()."group_perms WHERE permission_id = ?";
+      $db->Execute($query, array($id));
+
+      $query = "DELETE FROM ".cms_db_prefix()."permissions WHERE permission_id = ?";
+      $db->Execute($query, array($id));
+    }
+}
+
 function cms_mapi_create_permission($cms, $permission_name, $permission_text)
 {
 	global $gCms;
 	$db = &$gCms->GetDb();
 
-	$query = "SELECT permission_id FROM ".cms_db_prefix()."permissions WHERE permission_name =" . $db->qstr($permission_name); 
+	$query = "SELECT permission_id FROM ".cms_db_prefix()."permissions WHERE permission_name =" . $db->qstr($permission_name);
 	$result = $db->Execute($query);
 
 	if ($result && $result->RecordCount() < 1) {
@@ -855,7 +913,7 @@ function cms_mapi_create_permission($cms, $permission_name, $permission_text)
 		$query = "INSERT INTO ".cms_db_prefix()."permissions (permission_id, permission_name, permission_text, create_date, modified_date) VALUES ($new_id, ".$db->qstr($permission_name).",".$db->qstr($permission_text).",".$db->DBTimeStamp(time()).",".$db->DBTimeStamp(time()).")";
 		$db->Execute($query);
 	}
-	
+
 	if ($result)
 	{
 		$result->Close();
@@ -893,9 +951,9 @@ function is_directory_writable( $path )
 //     }
 
   if ( substr ( $path , strlen ( $path ) - 1 ) != '/' )
-    { 
-      $path .= '/' ; 
-    }     
+    {
+      $path .= '/' ;
+    }
 
   $result = true;
   if( $handle = @opendir( $path ) )
@@ -906,14 +964,14 @@ function is_directory_writable( $path )
 	    {
 	      continue;
 	    }
-	  
+
 	  $p = $path.$file;
-	  
+
 	  if( !@is_writable( $p ) )
 	    {
 	      return false;
 	    }
-	  
+
 	  if( @is_dir( $p ) )
 	    {
 	      $result = is_directory_writable( $p );
@@ -929,7 +987,7 @@ function is_directory_writable( $path )
     {
       return false;
     }
-  
+
   return true;
 }
 
@@ -937,7 +995,7 @@ function is_directory_writable( $path )
  * Return an array containing a list of files in a directory
  * performs a non recursive search
  * @param path - path to search
- * @param extensions - include only files matching these extensions 
+ * @param extensions - include only files matching these extensions
  *                     case insensitive, comma delimited
  */
 function get_matching_files($dir,$extensions = '',$excludedot = true,$excludedir = true,
@@ -984,7 +1042,7 @@ function get_matching_files($dir,$extensions = '',$excludedot = true,$excludedir
 **/
 function get_recursive_file_list ( $path , $excludes, $maxdepth = -1 , $mode = "FULL" , $d = 0 )
 {
-   if ( substr ( $path , strlen ( $path ) - 1 ) != '/' ) { $path .= '/' ; }     
+   if ( substr ( $path , strlen ( $path ) - 1 ) != '/' ) { $path .= '/' ; }
    $dirlist = array () ;
    if ( $mode != "FILES" ) { $dirlist[] = $path ; }
    if ( $handle = opendir ( $path ) )
@@ -1025,7 +1083,7 @@ function recursive_delete( $dirname )
 	      return false;
 	    }
 	}
-      else 
+      else
 	{
 	  recursive_delete($dirname."/".$file);
 	}
@@ -1051,7 +1109,7 @@ function chmod_r( $path, $mode )
   while( $file = readdir( $dh ) )
   {
     if( $file == '.' || $file == '..' ) continue;
-    
+
     $p = $path.DIRECTORY_SEPARATOR.$file;
     if( is_dir( $p ) )
     {
@@ -1105,14 +1163,15 @@ function munge_string_to_url($alias, $tolower = false)
 	// replacement.php is encoded utf-8 and must be the first modification of alias
 	include(dirname(__FILE__) . '/replacement.php');
 	$alias = str_replace($toreplace, $replacement, $alias);
-	
+
 	// lowercase only on empty aliases
 	if ($tolower == true)
 	{
 		$alias = strtolower($alias);
 	}
-		
-	$alias = preg_replace("/[^\w-]+/", "-", $alias);
+
+	$alias = preg_replace('/[^a-z0-9-_]+/i','-',$alias);
+	//$alias = preg_replace("/[^\w-]+/", "-", $alias);
 	$alias = trim($alias, '-');
 
 	return $alias;
@@ -1172,12 +1231,12 @@ if (!function_exists('array_walk_recursive'))
        {
            return false;
        }
-      
+
        if (!is_array($input))
        {
            return false;
        }
-      
+
        foreach ($input AS $key => $value)
        {
            if (is_array($input[$key]))
@@ -1195,7 +1254,7 @@ if (!function_exists('array_walk_recursive'))
                {
                    $funcname($value, $key);
                }
-              
+
                if ($value != $saved_value)
                {
                    $input[$key] = $value;
@@ -1260,7 +1319,7 @@ function cleanHtml($string, $remove = false) {
 
 
 /**
- * Method to sanitize all entries in 
+ * Method to sanitize all entries in
  * a hash
  *
 */
@@ -1337,7 +1396,7 @@ function cleanParamHash($modulename,$data,$map = false,
 				  break;
 			  } // switch
 		  } // if $paramtype
-			  
+
 		}
 
 	  // we didn't clean this yet
@@ -1431,7 +1490,7 @@ function can_users_upload()
     {
       return FALSE;
     }
-  
+
   // It all worked.
   return TRUE;
 }
@@ -1457,7 +1516,7 @@ function can_admin_upload()
 
   $my_uid = @getmyuid();
 
-  if( $my_uid === FALSE || $stat_index == FALSE || 
+  if( $my_uid === FALSE || $stat_index == FALSE ||
       $stat_moduleinterface == FALSE || $stat_uploads == FALSE ||
       $stat_modules == FALSE )
     {
@@ -1488,7 +1547,7 @@ function can_admin_upload()
     {
       return FALSE;
     }
-  
+
   // It all worked.
   return TRUE;
 }
@@ -1609,6 +1668,439 @@ function css_cache_clear($filename)
   @unlink($filename);
 }
 
+function cms_ipmatches($ip,$checklist)
+{
+  if( !function_exists('__testip') ) {
+  function __testip($range,$ip)
+  {
+    $result = 1;
 
+    // IP Pattern Matcher
+    // J.Adams <jna@retina.net>
+    //
+    // Matches:
+    //
+    // xxx.xxx.xxx.xxx        (exact)
+    // xxx.xxx.xxx.[yyy-zzz]  (range)
+    // xxx.xxx.xxx.xxx/nn    (nn = # bits, cisco style -- i.e. /24 = class C)
+    //
+    // Does not match:
+    // xxx.xxx.xxx.xx[yyy-zzz]  (range, partial octets not supported)
+
+    if (ereg("([0-9]+)\.([0-9]+)\.([0-9]+)\.([0-9]+)/([0-9]+)",$range,$regs)) {
+      // perform a mask match
+      $ipl = ip2long($ip);
+      $rangel = ip2long($regs[1] . "." . $regs[2] . "." . $regs[3] . "." . $regs[4]);
+
+      $maskl = 0;
+
+      for ($i = 0; $i< 31; $i++) {
+	if ($i < $regs[5]-1) {
+	  $maskl = $maskl + pow(2,(30-$i));
+	}
+      }
+
+      if (($maskl & $rangel) == ($maskl & $ipl)) {
+	return 1;
+      } else {
+	return 0;
+      }
+    } else {
+      // range based
+      $maskocts = split("\.",$range);
+      $ipocts = split("\.",$ip);
+
+      // perform a range match
+      for ($i=0; $i<4; $i++) {
+	if (ereg("\[([0-9]+)\-([0-9]+)\]",$maskocts[$i],$regs)) {
+	  if ( ($ipocts[$i] > $regs[2]) || ($ipocts[$i] < $regs[1])) {
+	    $result = 0;
+	  }
+	}
+	else
+	  {
+	    if ($maskocts[$i] <> $ipocts[$i]) {
+	      $result = 0;
+	    }
+	  }
+      }
+    }
+    return $result;
+  } // __testip
+  } // if
+
+  if( !is_array($checklist) )
+    {
+      $checklist = explode(',',$checklist);
+    }
+  foreach( $checklist as $one )
+    {
+      if( __testip(trim($one),$ip) ) return TRUE;
+    }
+  return FALSE;
+}
+
+/**
+ * @package	isemail
+ * @author	Dominic Sayers <dominic_sayers@hotmail.com>
+ * @copyright	2009 Dominic Sayers
+ * @license	http://www.opensource.org/licenses/cpal_1.0 Common Public Attribution License Version 1.0 (CPAL) license
+ * @link	http://www.dominicsayers.com/isemail
+ * @version	1.9 - Minor modifications to make it compatible with PHPLint
+ * @return boolean
+ * @var string  $email
+ * @var boolean $checkDNS
+*/
+function is_email( $email, $checkDNS=false ) {
+	// Check that $email is a valid address. Read the following RFCs to understand the constraints:
+	// 	(http://tools.ietf.org/html/rfc5322)
+	// 	(http://tools.ietf.org/html/rfc3696)
+	// 	(http://tools.ietf.org/html/rfc5321)
+	// 	(http://tools.ietf.org/html/rfc4291#section-2.2)
+	// 	(http://tools.ietf.org/html/rfc1123#section-2.1)
+
+	// the upper limit on address lengths should normally be considered to be 256
+	// 	(http://www.rfc-editor.org/errata_search.php?rfc=3696)
+	// 	NB I think John Klensin is misreading RFC 5321 and the the limit should actually be 254
+	// 	However, I will stick to the published number until it is changed.
+	//
+	// The maximum total length of a reverse-path or forward-path is 256
+	// characters (including the punctuation and element separators)
+	// 	(http://tools.ietf.org/html/rfc5321#section-4.5.3.1.3)
+	$emailLength = strlen($email);
+	if ($emailLength > 256)	return false;	// Too long
+
+	// Contemporary email addresses consist of a "local part" separated from
+	// a "domain part" (a fully-qualified domain name) by an at-sign ("@").
+	// 	(http://tools.ietf.org/html/rfc3696#section-3)
+	$atIndex = strrpos($email,'@');
+
+	if ($atIndex === false) return false;	// No at-sign
+	if ($atIndex === 0) return false;	// No local part
+	if ($atIndex === $emailLength) return false;	// No domain part
+
+	// Sanitize comments
+	// - remove nested comments, quotes and dots in comments
+	// - remove parentheses and dots from quoted strings
+	$braceDepth	= 0;
+	$inQuote	= false;
+	$escapeThisChar	= false;
+
+	for ($i = 0; $i < $emailLength; ++$i) {
+		$char = $email[$i];
+		$replaceChar = false;
+
+		if ($char === '\\') {
+			$escapeThisChar = !$escapeThisChar;	// Escape the next character?
+		} else {
+			switch ($char) {
+			case '(':
+				if ($escapeThisChar) {
+					$replaceChar = true;
+				} else {
+					if ($inQuote) {
+						$replaceChar = true;
+					} else {
+						if ($braceDepth++ > 0) $replaceChar = true;	// Increment brace depth
+					}
+				}
+
+				break;
+			case ')':
+				if ($escapeThisChar) {
+					$replaceChar = true;
+				} else {
+					if ($inQuote) {
+						$replaceChar = true;
+					} else {
+						if (--$braceDepth > 0) $replaceChar = true;	// Decrement brace depth
+						if ($braceDepth < 0) $braceDepth = 0;
+					}
+				}
+
+				break;
+			case '"':
+				if ($escapeThisChar) {
+					$replaceChar = true;
+				} else {
+					if ($braceDepth === 0) {
+						$inQuote = !$inQuote;	// Are we inside a quoted string?
+					} else {
+						$replaceChar = true;
+					}
+				}
+
+				break;
+			case '.':	// Dots don't help us either
+				if ($escapeThisChar) {
+					$replaceChar = true;
+				} else {
+					if ($braceDepth > 0) $replaceChar = true;
+				}
+
+				break;
+			default:
+			}
+
+			$escapeThisChar = false;
+			if ($replaceChar) $email[$i] = 'x';	// Replace the offending character with something harmless
+		}
+	}
+
+	$localPart	= substr($email, 0, $atIndex);
+	$domain		= substr($email, $atIndex + 1);
+	$FWS		= "(?:(?:(?:[ \\t]*(?:\\r\\n))?[ \\t]+)|(?:[ \\t]+(?:(?:\\r\\n)[ \\t]+)*))";	// Folding white space
+	// Let's check the local part for RFC compliance...
+	//
+	// local-part      =       dot-atom / quoted-string / obs-local-part
+	// obs-local-part  =       word *("." word)
+	// 	(http://tools.ietf.org/html/rfc5322#section-3.4.1)
+	//
+	// Problem: need to distinguish between "first.last" and "first"."last"
+	// (i.e. one element or two). And I suck at regexes.
+	$dotArray = preg_split('/\\.(?=(?:[^\\"]*\\"[^\\"]*\\")*(?![^\\"]*\\"))/m', $localPart);
+	$partLength	= 0;
+
+	foreach ($dotArray as $element) {
+		// Remove any leading or trailing FWS
+		$element = preg_replace("/^$FWS|$FWS\$/", '', $element);
+
+		// Then we need to remove all valid comments (i.e. those at the start or end of the element
+		$elementLength = strlen($element);
+
+		if ($element[0] === '(') {
+			$indexBrace = strpos($element, ')');
+			if ($indexBrace !== false) {
+				if (preg_match('/(?<!\\\\)[\\(\\)]/', substr($element, 1, $indexBrace - 1)) > 0) {
+					return false;	// Illegal characters in comment
+				}
+				$element = substr($element, $indexBrace + 1, $elementLength - $indexBrace - 1);
+				$elementLength = strlen($element);
+			}
+		}
+
+		if ($element[$elementLength - 1] === ')') {
+			$indexBrace = strrpos($element, '(');
+			if ($indexBrace !== false) {
+				if (preg_match('/(?<!\\\\)(?:[\\(\\)])/', substr($element, $indexBrace + 1, $elementLength - $indexBrace - 2)) > 0) {
+					return false;	// Illegal characters in comment
+				}
+				$element = substr($element, 0, $indexBrace);
+				$elementLength = strlen($element);
+			}
+		}
+
+		// Remove any leading or trailing FWS around the element (inside any comments)
+		$element = preg_replace("/^$FWS|$FWS\$/", '', $element);
+
+		// What's left counts towards the maximum length for this part
+		if ($partLength > 0) $partLength++;	// for the dot
+		$partLength += strlen($element);
+
+		// Each dot-delimited component can be an atom or a quoted string
+		// (because of the obs-local-part provision)
+		if (preg_match('/^"(?:.)*"$/s', $element) > 0) {
+			// Quoted-string tests:
+			//
+			// Remove any FWS
+			$element = preg_replace("/(?<!\\\\)$FWS/", '', $element);
+			// My regex skillz aren't up to distinguishing between \" \\" \\\" \\\\" etc.
+			// So remove all \\ from the string first...
+			$element = preg_replace('/\\\\\\\\/', ' ', $element);
+			if (preg_match('/(?<!\\\\|^)["\\r\\n\\x00](?!$)|\\\\"$|""/', $element) > 0)	return false;	// ", CR, LF and NUL must be escaped, "" is too short
+		} else {
+			// Unquoted string tests:
+			//
+			// Period (".") may...appear, but may not be used to start or end the
+			// local part, nor may two or more consecutive periods appear.
+			// 	(http://tools.ietf.org/html/rfc3696#section-3)
+			//
+			// A zero-length element implies a period at the beginning or end of the
+			// local part, or two periods together. Either way it's not allowed.
+			if ($element === '') return false;	// Dots in wrong place
+
+			// Any ASCII graphic (printing) character other than the
+			// at-sign ("@"), backslash, double quote, comma, or square brackets may
+			// appear without quoting.  If any of that list of excluded characters
+			// are to appear, they must be quoted
+			// 	(http://tools.ietf.org/html/rfc3696#section-3)
+			//
+			// Any excluded characters? i.e. 0x00-0x20, (, ), <, >, [, ], :, ;, @, \, comma, period, "
+			if (preg_match('/[\\x00-\\x20\\(\\)<>\\[\\]:;@\\\\,\\."]/', $element) > 0) return false;	// These characters must be in a quoted string
+		}
+	}
+
+	if ($partLength > 64) return false;	// Local part must be 64 characters or less
+
+	// Now let's check the domain part...
+	// The domain name can also be replaced by an IP address in square brackets
+	// 	(http://tools.ietf.org/html/rfc3696#section-3)
+	// 	(http://tools.ietf.org/html/rfc5321#section-4.1.3)
+	// 	(http://tools.ietf.org/html/rfc4291#section-2.2)
+	if (preg_match('/^\\[(.)+]$/', $domain) === 1) {
+		// It's an address-literal
+		$addressLiteral = substr($domain, 1, strlen($domain) - 2);
+		$matchesIP = array();
+
+		// Extract IPv4 part from the end of the address-literal (if there is one)
+		if (preg_match('/\\b(?:(?:25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)\\.){3}(?:25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)$/', $addressLiteral, $matchesIP) > 0) {
+			$index = strrpos($addressLiteral, $matchesIP[0]);
+
+			if ($index === 0) {
+				// Nothing there except a valid IPv4 address, so...
+				return true;
+			} else {
+				// Assume it's an attempt at a mixed address (IPv6 + IPv4)
+				if ($addressLiteral[$index - 1] !== ':') return false;	// Character preceding IPv4 address must be ':'
+				if (substr($addressLiteral, 0, 5) !== 'IPv6:') return false;	// RFC5321 section 4.1.3
+				$IPv6 = substr($addressLiteral, 5, ($index ===7) ? 2 : $index - 6);
+				$groupMax = 6;
+			}
+		} else {
+			// It must be an attempt at pure IPv6
+			if (substr($addressLiteral, 0, 5) !== 'IPv6:') return false;	// RFC5321 section 4.1.3
+			$IPv6 = substr($addressLiteral, 5);
+			$groupMax = 8;
+		}
+
+		$groupCount	= preg_match_all('/^[0-9a-fA-F]{0,4}|\\:[0-9a-fA-F]{0,4}|(.)/', $IPv6, $matchesIP);
+		$index = strpos($IPv6,'::');
+
+		if ($index === false) {
+			// We need exactly the right number of groups
+			if ($groupCount !== $groupMax) return false;	// RFC5321 section 4.1.3
+		} else {
+			if ($index !== strrpos($IPv6,'::')) return false;	// More than one '::'
+			$groupMax = ($index === 0 || $index === (strlen($IPv6) - 2)) ? $groupMax : $groupMax - 1;
+			if ($groupCount > $groupMax) return false;	// Too many IPv6 groups in address
+		}
+
+		// Check for unmatched characters
+		array_multisort($matchesIP[1], SORT_DESC);
+		if ($matchesIP[1][0] !== '') return false;	// Illegal characters in address
+
+		// It's a valid IPv6 address, so...
+		return true;
+	} else {
+		// It's a domain name...
+
+		// The syntax of a legal Internet host name was specified in RFC-952
+		// One aspect of host name syntax is hereby changed: the
+		// restriction on the first character is relaxed to allow either a
+		// letter or a digit.
+		// 	(http://tools.ietf.org/html/rfc1123#section-2.1)
+		//
+		// NB RFC 1123 updates RFC 1035, but this is not currently apparent from reading RFC 1035.
+		//
+		// Most common applications, including email and the Web, will generally not
+		// permit...escaped strings
+		// 	(http://tools.ietf.org/html/rfc3696#section-2)
+		//
+		// the better strategy has now become to make the "at least one period" test,
+		// to verify LDH conformance (including verification that the apparent TLD name
+		// is not all-numeric)
+		// 	(http://tools.ietf.org/html/rfc3696#section-2)
+		//
+		// Characters outside the set of alphabetic characters, digits, and hyphen MUST NOT appear in domain name
+		// labels for SMTP clients or servers
+		// 	(http://tools.ietf.org/html/rfc5321#section-4.1.2)
+		//
+		// RFC5321 precludes the use of a trailing dot in a domain name for SMTP purposes
+		// 	(http://tools.ietf.org/html/rfc5321#section-4.1.2)
+		$dotArray = preg_split('/\\.(?=(?:[^\\"]*\\"[^\\"]*\\")*(?![^\\"]*\\"))/m', $domain);
+		$partLength = 0;
+		if (count($dotArray) === 1) return false;	// Mail host can't be a TLD
+
+		foreach ($dotArray as $element) {
+			// Remove any leading or trailing FWS
+			$element = preg_replace("/^$FWS|$FWS\$/", '', $element);
+
+			// Then we need to remove all valid comments (i.e. those at the start or end of the element
+			$elementLength = strlen($element);
+
+			if ($element[0] === '(') {
+				$indexBrace = strpos($element, ')');
+				if ($indexBrace !== false) {
+					if (preg_match('/(?<!\\\\)[\\(\\)]/', substr($element, 1, $indexBrace - 1)) > 0) {
+						return false;	// Illegal characters in comment
+					}
+					$element = substr($element, $indexBrace + 1, $elementLength - $indexBrace - 1);
+					$elementLength = strlen($element);
+				}
+			}
+
+			if ($element[$elementLength - 1] === ')') {
+				$indexBrace = strrpos($element, '(');
+				if ($indexBrace !== false) {
+					if (preg_match('/(?<!\\\\)(?:[\\(\\)])/', substr($element, $indexBrace + 1, $elementLength - $indexBrace - 2)) > 0) {
+						return false;	// Illegal characters in comment
+					}
+					$element = substr($element, 0, $indexBrace);
+					$elementLength = strlen($element);
+				}
+			}
+
+			// Remove any leading or trailing FWS around the element (inside any comments)
+			$element = preg_replace("/^$FWS|$FWS\$/", '', $element);
+
+			// What's left counts towards the maximum length for this part
+			if ($partLength > 0) $partLength++;	// for the dot
+			$partLength += strlen($element);
+
+			// The DNS defines domain name syntax very generally -- a
+			// string of labels each containing up to 63 8-bit octets,
+			// separated by dots, and with a maximum total of 255
+			// octets.
+			// 	(http://tools.ietf.org/html/rfc1123#section-6.1.3.5)
+			if ($elementLength > 63) return false;	// Label must be 63 characters or less
+
+			// Each dot-delimited component must be atext
+			// A zero-length element implies a period at the beginning or end of the
+			// local part, or two periods together. Either way it's not allowed.
+			if ($elementLength === 0) return false;	// Dots in wrong place
+
+			// Any ASCII graphic (printing) character other than the
+			// at-sign ("@"), backslash, double quote, comma, or square brackets may
+			// appear without quoting.  If any of that list of excluded characters
+			// are to appear, they must be quoted
+			// 	(http://tools.ietf.org/html/rfc3696#section-3)
+			//
+			// If the hyphen is used, it is not permitted to appear at
+			// either the beginning or end of a label.
+			// 	(http://tools.ietf.org/html/rfc3696#section-2)
+			//
+			// Any excluded characters? i.e. 0x00-0x20, (, ), <, >, [, ], :, ;, @, \, comma, period, "
+			//if (preg_match('/[\\x00-\\x20\\(\\)<>\\[\\]:;@\\\\,\\."]|^-|-$/', $element) > 0) {
+			if (preg_match('/[\\x00-\\x20\\(\\)<>\\[\\]:;@\\\\,\\."]$/', $element) > 0) {
+				return false;
+			}
+		}
+
+		if ($partLength > 255) return false;	// Local part must be 64 characters or less
+		if (preg_match('/^[0-9]+$/', $element) > 0)	return false;	// TLD can't be all-numeric
+
+		// Check DNS?
+		if ($checkDNS && function_exists('checkdnsrr')) {
+			if (!(checkdnsrr($domain, 'A') || checkdnsrr($domain, 'MX'))) {
+				return false;	// Domain doesn't actually exist
+			}
+		}
+	}
+
+	// Eliminate all other factors, and the one which remains must be the truth.
+	// (Sherlock Holmes, The Sign of Four)
+	return true;
+}
+
+function get_secure_param()
+{
+  $urlext = '?';
+  $str = strtolower(ini_get('session.use_cookies'));
+  if( $str == '0' || $str == 'off' ) {
+    $urlext .= htmlspecialchars(SID).'&';
+  }
+  $urlext .= CMS_SECURE_PARAM_NAME.'='.$_SESSION[CMS_USER_KEY];
+  return $urlext;
+}
 # vim:ts=4 sw=4 noet
 ?>
